#include <std_include.hpp>
#include "loader/component_loader.hpp"

#include <utils/string.hpp>

#include "game.hpp"
#include "dvars.hpp"
#include <component/console.hpp>
#include <utils/hook.hpp>

namespace dvars
{
	game::dvar_t* aimassist_enabled = nullptr;

	game::dvar_t* con_inputBoxColor = nullptr;
	game::dvar_t* con_inputHintBoxColor = nullptr;
	game::dvar_t* con_outputBarColor = nullptr;
	game::dvar_t* con_outputSliderColor = nullptr;
	game::dvar_t* con_outputWindowColor = nullptr;
	game::dvar_t* con_inputDvarMatchColor = nullptr;
	game::dvar_t* con_inputDvarValueColor = nullptr;
	game::dvar_t* con_inputDvarInactiveValueColor = nullptr;
	game::dvar_t* con_inputCmdMatchColor = nullptr;

	game::dvar_t* jump_enableFallDamage;

	game::dvar_t* r_fullbright;
	game::dvar_t* r_chams;

	game::dvar_t* cg_legacyCrashHandling;

	std::string dvar_get_vector_domain(const int components, const game::dvar_limits& domain)
	{
		if (domain.vector.min == -FLT_MAX)
		{
			if (domain.vector.max == FLT_MAX)
			{
				return utils::string::va("Domain is any %iD vector", components);
			}
			else
			{
				return utils::string::va("Domain is any %iD vector with components %g or smaller", components,
					domain.vector.max);
			}
		}
		else if (domain.vector.max == FLT_MAX)
		{
			return utils::string::va("Domain is any %iD vector with components %g or bigger", components,
				domain.vector.min);
		}
		else
		{
			return utils::string::va("Domain is any %iD vector with components from %g to %g", components,
				domain.vector.min, domain.vector.max);
		}
	}

	std::string dvar_get_domain(const game::dvar_type type, const game::dvar_limits& domain)
	{
		std::string str;

		switch (type)
		{
		case game::dvar_type::boolean:
			return "Domain is 0 or 1"s;

		case game::dvar_type::value:
			if (domain.value.min == -FLT_MAX)
			{
				if (domain.value.max == FLT_MAX)
				{
					return "Domain is any number"s;
				}
				else
				{
					return utils::string::va("Domain is any number %g or smaller", domain.value.max);
				}
			}
			else if (domain.value.max == FLT_MAX)
			{
				return utils::string::va("Domain is any number %g or bigger", domain.value.min);
			}
			else
			{
				return utils::string::va("Domain is any number from %g to %g", domain.value.min, domain.value.max);
			}

		case game::dvar_type::vec2:
			return dvar_get_vector_domain(2, domain);

		case game::dvar_type::rgb:
		case game::dvar_type::vec3:
			return dvar_get_vector_domain(3, domain);

		case game::dvar_type::vec4:
			return dvar_get_vector_domain(4, domain);

		case game::dvar_type::integer:
			if (domain.enumeration.stringCount == INT_MIN)
			{
				if (domain.integer.max == INT_MAX)
				{
					return "Domain is any integer"s;
				}
				else
				{
					return utils::string::va("Domain is any integer %i or smaller", domain.integer.max);
				}
			}
			else if (domain.integer.max == INT_MAX)
			{
				return utils::string::va("Domain is any integer %i or bigger", domain.integer.min);
			}
			else
			{
				return utils::string::va("Domain is any integer from %i to %i", domain.integer.min, domain.integer.max);
			}

		case game::dvar_type::color:
			return "Domain is any 4-component color, in RGBA format"s;

		case game::dvar_type::enumeration:
			str = "Domain is one of the following:"s;

			for (auto string_index = 0; string_index < domain.enumeration.stringCount; ++string_index)
			{
				str += utils::string::va("\n  %2i: %s", string_index, domain.enumeration.strings[string_index]);
			}

			return str;

		case game::dvar_type::string:
			return "Domain is any text"s;

		default:
			return utils::string::va("unhandled dvar type '%i'", type);
		}
	}

	namespace
	{
		template <typename T>
		T* find_dvar(std::unordered_map<std::string, T>& map, const std::string& name)
		{
			auto i = map.find(name);
			if (i != map.end())
			{
				return &i->second;
			}

			return nullptr;
		}

		bool find_dvar(std::unordered_set<std::string>& set, const std::string& name)
		{
			return set.find(name) != set.end();
		}
	}

	std::vector<dvar_info> dvar_list =
	{
		{"accessToSubscriberContent", "Whether to display the subscriber maps."},
		{"aci", ""},
		{"actionSlotsHide", "Hide the actionslots."},
		{"ai_grenadeReturn_approachMinDot", "Minimal dot product between the approach and throw vectors to perform a grenade return"},
		{"ai_grenadeReturn_debug", "Turns on debug info for AI grenade returns"},
		{"ai_grenadeReturn_extraFuseTime", "The amount of time (in ms) to add to a grenade fuse when trying to return grenade that's below minFuseTime"},
		{"ai_grenadeReturn_minDistSqr", "Minimal distance to a grenade to consider it for a return so that transition anims will play"},
		{"ai_grenadeReturn_minFuseTime", "If the fuse time drops below this value when an ally is attempting to return a grenade, add extra fuse time"},
		{"ai_grenadeReturn_stationary", "If set, AI will attempt to return grenades that they are within pickup distance - regardless of min dist"},
		{"ai_grenadeReturn_traceToGrenade", "If set, AI will only attempt to return grenades when they have a clear sight trace to the grenade"},
		{"ai_threatUpdateInterval", "AI target threat update interval in milliseconds"},
		{"aim_autoaim_enabled", ""},
		{"aim_target_sentient_radius", "The radius used to calculate target bounds for a sentient(actor or player)"},
		{"ammoCounterHide", "Hide the Ammo Counter"},
		{"armory_contentpacks_enabled", "Allowed armory content packs. 0: none , 1: first armory content pack enabled, 2: first and second armory content pack enabled"},
		{"badHost_detectMinServerTime", "Time in MS before the bad host dection system kicks in after match start"},
		{"badhost_maxDoISuckFrames", "Max lagged frames need to end match"},
		{"band_12players", "12 player bandwidth req'd"},
		{"band_18players", "18 player bandwidth req'd"},
		{"band_2players", "2 player bandwidth req'd"},
		{"band_4players", "4 player bandwidth req'd"},
		{"band_8players", "8 player bandwidth req'd"},
		{"bg_allowScuffFootsteps", "If true, scuff sounds will be played when the player rotates in place."},
		{"bg_bulletExplDmgFactor", "Weapon damage multiplier that will be applied at the center of the slash damage area."},
		{"bg_bulletExplRadius", "The radius of the bullet splash damage, where the damage gradually falls off to 0."},
		{"bg_compassShowEnemies", "Whether enemies are visible on the compass at all times"},
		{"bg_idleSwingSpeed", "The rate at which the player's legs swing around when idle (multi-player only)"},
		{"bg_shieldHitEncodeHeightVM", "The decoding range, in height, of a client's viewmodel shield."},
		{"bg_shieldHitEncodeHeightWorld", "The encoding range, in height, of a client's world shield.  A hit in this range is encoded into one of 8 rows."},
		{"bg_shieldHitEncodeWidthVM", "The decoding range, in width, of a client's viewmodel shield."},
		{"bg_shieldHitEncodeWidthWorld", "The encoding range, in width, of a client's world shield.  A hit in this range is encoded into one of 16 collumns."},
		{"bg_shock_fadeOverride", "Override the time for the shellshock kick effect to fade in MP"},
		{"bg_shock_lookControl", "Alter player control during shellshock"},
		{"bg_shock_lookControl_fadeTime", "The time for the shellshock player control to fade in seconds"},
		{"bg_shock_lookControl_maxpitchspeed", "Maximum pitch movement rate while shellshocked in degrees per second"},
		{"bg_shock_lookControl_maxyawspeed", "Maximum yaw movement rate while shell shocked in degrees per second"},
		{"bg_shock_lookControl_mousesensitivityscale", "Sensitivity scale to apply to a shellshocked player"},
		{"bg_shock_movement", "Affect player's movement speed duringi shellshock"},
		{"bg_shock_screenBlurBlendFadeTime", "The amount of time in seconds for the shellshock effect to fade"},
		{"bg_shock_screenBlurBlendTime", "The amount of time in seconds for the shellshock effect to fade"},
		{"bg_shock_screenFlashShotFadeTime", "In seconds, how soon from the end of the effect to start blending out the whiteout layer."},
		{"bg_shock_screenFlashWhiteFadeTime", "In seconds, how soon from the end of the effect to start blending out the whiteout layer."},
		{"bg_shock_screenType", "Shell shock screen effect type"},
		{"bg_shock_sound", "Play shell shock sound"},
		{"bg_shock_soundDryLevel", "Shell shock sound dry level"},
		{"bg_shock_soundEnd", "Shellshock end sound alias"},
		{"bg_shock_soundEndAbort", "Shellshock aborted end sound alias"},
		{"bg_shock_soundFadeInTime", "Shell shock sound fade in time in seconds"},
		{"bg_shock_soundFadeOutTime", "Shell shock sound fade out time in seconds"},
		{"bg_shock_soundLoop", "Shellshock loop alias"},
		{"bg_shock_soundLoopEndDelay", "Sound loop end offset time from the end of the shellshock in seconds"},
		{"bg_shock_soundLoopFadeTime", "Shell shock sound loop fade time in seconds"},
		{"bg_shock_soundLoopSilent", "The sound that gets blended with the shellshock loop alias"},
		{"bg_shock_soundModEndDelay", "The delay from the end of the shell shock to the end of the sound modification"},
		{"bg_shock_soundRoomType", "Shell shock sound reverb room type"},
		{"bg_shock_soundSubmix", "Shell shock submix to apply"},
		{"bg_shock_soundWetLevel", "Shell shock sound wet level"},
		{"bg_shock_viewKickFadeTime", "The time for the shellshock kick effect to fade"},
		{"bg_shock_viewKickPeriod", "The period of the shellshock view kick effect"},
		{"bg_shock_viewKickRadius", "Shell shock kick radius"},
		{"bg_swingSpeed", "The rate at which the player's legs swing around when idle (multi-player only)"},
		{"bg_torsoSwingSpeed", "The rate at which the player's torso swings around when strafing (multi-player only)"},
		{"boostcheatHeadshotsTotalCoef", ""},
		{"boostcheatHeadshotsTotalMean", ""},
		{"boostcheatHeadshotsTotalStddev", ""},
		{"boostcheatIntercept", ""},
		{"boostcheatKillerXAnomalyCoef", ""},
		{"boostcheatKillerXAnomalyMean", ""},
		{"boostcheatKillerXAnomalyStddev", ""},
		{"boostcheatKillerYAnomalyCoef", ""},
		{"boostcheatKillerYAnomalyMean", ""},
		{"boostcheatKillerYAnomalyStddev", ""},
		{"boostcheatMeanDistanceMostKilledPlayerTraveledMean", ""},
		{"boostcheatMeanDistanceVictimTraveledCoef", ""},
		{"boostcheatMeanDistanceVictimTraveledMean", ""},
		{"boostcheatMeanDistanceVictimTraveledStddev", ""},
		{"boostcheatMeanMostKilledPlayerLifetimeMillisecondsMean", ""},
		{"boostcheatMostKilledPlayerHKRatioCoef", ""},
		{"boostcheatMostKilledPlayerHKRatioMean", ""},
		{"boostcheatMostKilledPlayerHKRatioStddev", ""},
		{"boostcheatMostKilledPlayerKillsRatioCoef", ""},
		{"boostcheatMostKilledPlayerKillsRatioMean", ""},
		{"boostcheatMostKilledPlayerKillsRatioStddev", ""},
		{"boostcheatMostKilledPlayerKillsTotalCoef", ""},
		{"boostcheatMostKilledPlayerKillsTotalMean", ""},
		{"boostcheatMostKilledPlayerKillsTotalStddev", ""},
		{"boostcheatMostKilledPlayerKillTimestampsAnomalyMean", ""},
		{"boostcheatVictimXAnomalyCoef", ""},
		{"boostcheatVictimXAnomalyMean", ""},
		{"boostcheatVictimXAnomalyStddev", ""},
		{"boostcheatVictimYAnomalyCoef", ""},
		{"boostcheatVictimYAnomalyMean", ""},
		{"boostcheatVictimYAnomalyStddev", ""},
		{"bot_DifficultyDefault", "default difficulty level of bots"},
		{"ca_auto_signin", "CoD Anywhere start sign-in task automatically on startup or first party sign-in"},
		{"ca_do_mlc", "CoD Anywhere Do Multi Login check"},
		{"ca_intra_only", "CoD Anywhere Intra Network Only"},
		{"ca_require_signin", "CoD Anywhere require sign in to enter MP"},
		{"ca_show_signup_request", "CoD Anywhere should you show new users a popup requesting they create a CoD Account?"},
		{"camera_thirdPerson", "Use third person view globally"},
		{"cameraShakeRemoteHelo_Angles", "Remote helicopter gunner cam, range to shake the view."},
		{"cameraShakeRemoteHelo_Freqs", "Remote helicopter gunner cam, how fast to shake."},
		{"cameraShakeRemoteHelo_SpeedRange", "Remote helicopter gunner cam, range of missile speed to scale the shaking."},
		{"cameraShakeRemoteMissile_Angles", "Remote missile-cam, range to shake the view."},
		{"cameraShakeRemoteMissile_Freqs", "Remote missile-cam, how fast to shake."},
		{"cameraShakeRemoteMissile_SpeedRange", "Remote missile-cam, range of missile speed to scale the shaking."},
		{"cg_airstrikeCamFstop", "Airstrike kill camera aperture. Lower f-stop yields a shallower depth of field. Typical values range from 1 to 22"},
		{"cg_airstrikeKillCamFarBlur", ""},
		{"cg_airstrikeKillCamFarBlurDist", ""},
		{"cg_airstrikeKillCamFarBlurStart", ""},
		{"cg_airstrikeKillCamFov", "Airstrike kill camera field of view."},
		{"cg_airstrikeKillCamNearBlur", ""},
		{"cg_airstrikeKillCamNearBlurEnd", ""},
		{"cg_airstrikeKillCamNearBlurStart", ""},
		{"cg_blood", "Show Blood"},
		{"cg_bloodThickColor", "Color of the blood overlay's thick blood splatter"},
		{"cg_bloodThinColor", "Color of the blood overlay's thin blood splatter"},
		{"cg_brass", "Weapons eject brass"},
		{"cg_centertime", "The time for a center printed message to fade"},
		{"cg_chatHeight", "The font height of a chat message"},
		{"cg_chatTime", "The amount of time that a chat message is visible"},
		{"cg_ColorBlind_EnemyTeam", "Enemy team color for color blind people"},
		{"cg_ColorBlind_MyParty", "Player party color for color blind people"},
		{"cg_ColorBlind_MyTeam", "Player team color for color blind people"},
		{"cg_connectionIconSize", "Size of the connection icon"},
		{"cg_constantSizeHeadIcons", "Head icons are the same size regardless of distance from the player"},
		{"cg_crosshairAlpha", "The alpha value of the crosshair"},
		{"cg_crosshairAlphaMin", "The minimum alpha value of the crosshair when it fades in"},
		{"cg_crosshairDynamic", "Crosshair is Dynamic"},
		{"cg_crosshairEnemyColor", "The crosshair color when over an enemy"},
		{"cg_crosshairVerticalOffset", "Amount to vertically offset the crosshair from the center."},
		{"cg_cullBulletAngle", "Cull bullet trajectories that don't fall within this fov"},
		{"cg_cullBullets", "Whether to cull bullet fire prediction if trajectory doesn't pass your view or anywhere near you"},
		{"cg_cursorHints", "Draw cursor hints where:\n 0: no hints"},
		{"cg_deadChatWithDead", "If true, dead players can all chat together, regardless of team"},
		{"cg_deadChatWithTeam", "If true, dead players can talk to living players on their team"},
		{"cg_deadHearAllLiving", "If true, dead players can hear all living players talk"},
		{"cg_deadHearTeamLiving", "If true, dead players can hear living players on their team talk"},
		{"cg_descriptiveText", "Draw descriptive spectator messages"},
		{"cg_draw2D", "Draw 2D screen elements"},
		{"cg_drawBreathHint", "Draw a 'hold breath to steady' hint"},
		{"cg_drawBuildName", "Draw build name"},
		{"cg_drawCrosshair", "Turn on weapon crosshair"},
		{"cg_drawCrosshairNames", "Draw the name of an enemy under the crosshair"},
		{"cg_drawCrosshairNamesPosX", ""},
		{"cg_drawCrosshairNamesPosY", ""},
		{"cg_drawDamageDirection", "Draw hit direction arrow."},
		{"cg_drawDamageFlash", "Draw flash when hit."},
		{"cg_drawDoubleTapDetonateHint", "Draw a 'double tap to detonate grenade' hint"},
		{"cg_drawEffectNum", "Draw counts of effects and elements"},
		{"cg_drawFPS", "Draw frames per second"},
		{"cg_drawFPSLabels", "Draw FPS Info Labels"},
		{"cg_drawFriendlyHUDGrenades", "Draw grenade warning indicators for friendly grenades (should be true if friendly-fire is enabled)"},
		{"cg_drawFriendlyNames", "Whether to show friendly names in game"},
		{"cg_drawFriendlyNamesAlways", "Whether to always show friendly names in game (for certain gametypes)"},
		{"cg_drawGun", "Draw the view model"},
		{"cg_drawHealth", "Draw health bar"},
		{"cg_drawMantleHint", "Draw a 'press key to mantle' hint"},
		{"cg_drawMaterial", "Draw debugging information for materials"},
		{"cg_drawpaused", "Draw paused screen"},
		{"cg_drawScriptUsage", "Draw debugging information for scripts"},
		{"cg_drawSnapshot", "Draw debugging information for snapshots"},
		{"cg_drawStatsSource", "Draw stats source"},
		{"cg_drawTalk", "Controls which icons CG_TALKER ownerdraw draws"},
		{"cg_drawTurretCrosshair", "Draw a cross hair when using a turret"},
		{"cg_drawViewpos", "Draw viewpos"},
		{"cg_e3TrailerHacks", "Tweaks for trailer recording"},
		{"cg_equipmentSounds", "Play equipment sounds"},
		{"cg_errordecay", "Decay for predicted error"},
		{"cg_everyoneHearsEveryone", "If true, all players can all chat together, regardless of team or death"},
		{"cg_explosiveKillCamBackDist", "Explosive kill camera: distance of camera backwards from explosive."},
		{"cg_explosiveKillCamGroundBackDist", "Explosive kill camera when stuck to ground: distance of camera backwards from explosive."},
		{"cg_explosiveKillCamGroundUpDist", "Explosive kill camera when stuck to ground: distance of camera backwards from explosive."},
		{"cg_explosiveKillCamStopDecelDist", "Rocket and Grenade Launcher kill camera: distance from player to begin coming to rest"},
		{"cg_explosiveKillCamStopDist", "Rocket and Grenade Launcher kill camera: distance from player to begin coming to rest"},
		{"cg_explosiveKillCamUpDist", "Explosive kill camera: distance of camera backwards from explosive."},
		{"cg_explosiveKillCamWallOutDist", "Explosive kill camera when stuck to wall: distance of camera out from wall."},
		{"cg_explosiveKillCamWallSideDist", "Explosive kill camera when stuck to wall: distance of camera out from wall."},
		{"cg_flashbangNameFadeIn", "Time in milliseconds to fade in friendly names"},
		{"cg_flashbangNameFadeOut", "Time in milliseconds to fade out friendly names"},
		{"cg_foliagesnd_alias", "The sound that plays when an actor or player enters a foliage clip brush."},
		{"cg_footsteps", "Play footstep sounds that are NOT sprint"},
		{"cg_footstepsSprint", "Play sprint footstep sounds"},
		{"cg_fov", "The field of view angle in degrees"},
		{"cg_fovMin", "The minimum possible field of view"},
		{"cg_fovScale", "Scale applied to the field of view"},
		{"cg_friendlyNameFadeIn", "Time in milliseconds to fade in friendly names"},
		{"cg_friendlyNameFadeOut", "Time in milliseconds to fade out friendly names"},
		{"cg_gameBoldMessageWidth", "The maximum character width of the bold game messages"},
		{"cg_gameMessageWidth", "The maximum character width of the game messages"},
		{"cg_gun_x", "Forward position of the viewmodel"},
		{"cg_gun_y", "Right position of the viewmodel"},
		{"cg_gun_z", "Up position of the viewmodel"},
		{"cg_headIconMinScreenRadius", "The minumum radius of a head icon on the screen"},
		{"cg_hearKillerTime", "Duration (in milliseconds) to hear the person you just killed"},
		{"cg_hearVictimEnabled", "If true, you can hear the person you just killed"},
		{"cg_hearVictimTime", "Duration (in milliseconds) to hear the person you just killed"},
		{"cg_heliKillCamFarBlur", ""},
		{"cg_heliKillCamFarBlurDist", ""},
		{"cg_heliKillCamFarBlurStart", ""},
		{"cg_heliKillCamFov", "Helicopter kill camera field of view."},
		{"cg_heliKillCamFstop", "Helicopter kill camera aperture. Lower f-stop yields a shallower depth of field. Typical values range from 1 to 22"},
		{"cg_heliKillCamNearBlur", ""},
		{"cg_heliKillCamNearBlurEnd", ""},
		{"cg_heliKillCamNearBlurStart", ""},
		{"cg_hintFadeTime", "Time in milliseconds for the cursor hint to fade"},
		{"cg_hudChatIntermissionPosition", "Position of the HUD chat box during intermission"},
		{"cg_hudChatPosition", "Position of the HUD chat box"},
		{"cg_hudDamageIconHeight", "The height of the damage icon"},
		{"cg_hudDamageIconInScope", "Draw damage icons when aiming down the sight of a scoped weapon"},
		{"cg_hudDamageIconOffset", "The offset from the center of the damage icon"},
		{"cg_hudDamageIconOverlayTime", "The amount of time (in ms) for the overlay portion of the damage icon to stay on screen"},
		{"cg_hudDamageIconStartFadeTime", "The amount of time (in ms) before the damage icon begins to fade"},
		{"cg_hudDamageIconTime", "The amount of time for the damage icon to stay on screen after damage is taken"},
		{"cg_hudDamageIconWidth", "The width of the damage icon"},
		{"cg_hudGrenadeIconEnabledFlash", "Show the grenade indicator for flash grenades"},
		{"cg_hudGrenadeIconHeight", "The height of the grenade indicator icon"},
		{"cg_hudGrenadeIconInScope", "Show the grenade indicator when aiming down the sight of a scoped weapon"},
		{"cg_hudGrenadeIconMaxRangeFlash", "The minimum distance that a flashbang has to be from a player in order to be shown on the grenade indicator"},
		{"cg_hudGrenadeIconMaxRangeFrag", "The minimum distance that a grenade has to be from a player in order to be shown on the grenade indicator"},
		{"cg_hudGrenadeIconOffset", "The offset from the center of the screen for a grenade icon"},
		{"cg_hudGrenadeIconWidth", "The width of the grenade indicator icon"},
		{"cg_hudGrenadePointerHeight", "The height of the grenade indicator pointer"},
		{"cg_hudGrenadePointerPivot", "The pivot point of th grenade indicator pointer"},
		{"cg_hudGrenadePointerPulseFreq", "The number of times per second that the grenade indicator flashes in Hertz"},
		{"cg_hudGrenadePointerPulseMax", "The maximum alpha of the grenade indicator pulse. Values higher than 1 will cause the indicator to remain at full brightness for longer"},
		{"cg_hudGrenadePointerPulseMin", "The minimum alpha of the grenade indicator pulse. Values lower than 0 will cause the indicator to remain at full transparency for longer"},
		{"cg_hudGrenadePointerWidth", "The width of the grenade indicator pointer"},
		{"cg_hudLegacySplitscreenScale", "Screen scale for hud elements in splitscreen"},
		{"cg_hudLighting_basic_additiveLumOffset", "[basic] Offset applied to additive light color."},
		{"cg_hudLighting_basic_additiveLumScale", "[basic] Scale applied to additive light color."},
		{"cg_hudLighting_basic_additiveOffset", ""},
		{"cg_hudLighting_basic_additiveScale", ""},
		{"cg_hudLighting_basic_ambientLumOffset", "[basic] Offset applied to ambient light color."},
		{"cg_hudLighting_basic_ambientLumScale", "[basic] Scale applied to ambient light color."},
		{"cg_hudLighting_basic_ambientOffset", ""},
		{"cg_hudLighting_basic_ambientScale", ""},
		{"cg_hudLighting_basic_diffuseLumOffset", "[basic] Offset applied to diffuse light color."},
		{"cg_hudLighting_basic_diffuseLumScale", "[basic] Scale applied to diffuse light color."},
		{"cg_hudLighting_basic_diffuseOffset", ""},
		{"cg_hudLighting_basic_diffuseScale", ""},
		{"cg_hudLighting_basic_specExponent", "[basic] Specular exponent.  Higher values result in sharper highlights."},
		{"cg_hudLighting_basic_specLumOffset", "[basic] Offset applied to spec light luminance."},
		{"cg_hudLighting_basic_specLumScale", "[basic] Scale applied to spec light luminance."},
		{"cg_hudLighting_basic_specOffset", ""},
		{"cg_hudLighting_basic_specScale", ""},
		{"cg_hudLighting_blood_additiveLumOffset", "[blood] Offset applied to additive light color."},
		{"cg_hudLighting_blood_additiveLumScale", "[blood] Scale applied to additive light color."},
		{"cg_hudLighting_blood_additiveOffset", ""},
		{"cg_hudLighting_blood_additiveScale", ""},
		{"cg_hudLighting_blood_ambientLumOffset", "[blood] Offset applied to ambient light color."},
		{"cg_hudLighting_blood_ambientLumScale", "[blood] Scale applied to ambient light color."},
		{"cg_hudLighting_blood_ambientOffset", ""},
		{"cg_hudLighting_blood_ambientScale", ""},
		{"cg_hudLighting_blood_diffuseLumOffset", "[blood] Offset applied to diffuse light color."},
		{"cg_hudLighting_blood_diffuseLumScale", "[blood] Scale applied to diffuse light color."},
		{"cg_hudLighting_blood_diffuseOffset", ""},
		{"cg_hudLighting_blood_diffuseScale", ""},
		{"cg_hudLighting_blood_specExponent", "[blood] Specular exponent.  Higher values result in sharper highlights."},
		{"cg_hudLighting_blood_specLumOffset", "[blood] Offset applied to spec light luminance."},
		{"cg_hudLighting_blood_specLumScale", "[blood] Scale applied to spec light luminance."},
		{"cg_hudLighting_blood_specOffset", ""},
		{"cg_hudLighting_blood_specScale", ""},
		{"cg_hudLighting_fadeSharpness", "This controls how sharp the lines are when fading using the mask alpha.  Higher values are sharper."},
		{"cg_hudMapBorderWidth", "The size of the full map's border, filled by the CG_PLAYER_FULLMAP_BORDER ownerdraw"},
		{"cg_hudMapFriendlyHeight", ""},
		{"cg_hudMapFriendlyWidth", ""},
		{"cg_hudMapPlayerHeight", ""},
		{"cg_hudMapPlayerWidth", ""},
		{"cg_hudMapRadarLineThickness", "Thickness, relative to the map width, of the radar texture that sweeps across the full screen map"},
		{"cg_hudObjectiveTextScale", ""},
		{"cg_hudProneY", "Virtual screen y coordinate of the prone blocked message"},
		{"cg_hudSayPosition", "Position of the HUD say box"},
		{"cg_hudSplitscreenCompassElementScale", "Scale value to apply to compass elements in splitscreen"},
		{"cg_hudSplitscreenCompassScale", "Scale value to apply to the compass in splitscreen"},
		{"cg_hudSplitscreenStanceScale", "Scale value to apply to the stance HUD element in splitscreen"},
		{"cg_hudStanceFlash", "The background color of the flash when the stance changes"},
		{"cg_hudVotePosition", "Position of the HUD vote box"},
		{"cg_invalidCmdHintBlinkInterval", "Blink rate of an invalid command hint"},
		{"cg_invalidCmdHintDuration", "Duration of an invalid command hint"},
		{"cg_javelinKillCamCloseZDist", "Javelin kill camera: closest distance above the target."},
		{"cg_javelinKillCamDownDist", "Javelin kill camera: distance to follow during ascent."},
		{"cg_javelinKillCamFov", "Javelin kill camera: fov"},
		{"cg_javelinKillCamLookLerpDist", "Javelin kill camera: distance over which to lerp to look at player during descent.  A value of zero means don't lerp at all."},
		{"cg_javelinKillCamPassDist", "Javelin kill camera: distance away when passing."},
		{"cg_javelinKillCamPassTime", "Javelin kill camera: time in seconds to pass javelin on the way up"},
		{"cg_javelinKillCamUpDist", "Javelin kill camera: distance to follow during ascent."},
		{"cg_killCamDefaultLerpTime", "Default time used to lerp between killcam entities."},
		{"cg_killCamTurretLerpTime", "Time used to lerp to a killcam entity of the TURRET type."},
		{"cg_landingSounds", "Play landing on surface sounds"},
		{"cg_largeExplosiveKillCamBackDist", "Large Explosive kill camera: distance of camera backwards from explosive."},
		{"cg_largeExplosiveKillCamUpDist", "Large Explosive kill camera: distance of camera backwards from explosive."},
		{"cg_mapLocationSelectionCursorSpeed", "Speed of the cursor when selecting a location on the map"},
		{"cg_marks_ents_player_only", "Marks on entities from players' bullets only."},
		{"cg_minCullBulletDist", "Don't cull bullet trajectories that are within this distance to you."},
		{"cg_objectiveText", ""},
		{"cg_overheadIconSize", "The maximum size to show overhead icons like 'rank'"},
		{"cg_overheadNamesFarDist", "The far distance at which name sizes are scaled by cg_overheadNamesFarScale"},
		{"cg_overheadNamesFarScale", "The amount to scale overhead name sizes at cg_overheadNamesFarDist"},
		{"cg_overheadNamesFont", "Font for overhead names ( see menudefinition.h )"},
		{"cg_overheadNamesGlow", "Glow color for overhead names"},
		{"cg_overheadNamesMaxDist", "The maximum distance for showing friendly player names"},
		{"cg_overheadNamesNearDist", "The near distance at which names are full size"},
		{"cg_overheadNamesSize", "The maximum size to show overhead names"},
		{"cg_overheadRankSize", "The size to show rank text"},
		{"cg_remoteMissileKillCamBackDist", "Remote missile kill camera: distance of camera backwards from rocket."},
		{"cg_remoteMissileKillCamUpDist", "Remote missile kill camera: distance of camera backwards from rocket."},
		{"cg_rocketKillCamBackDist", "Rocket kill camera: distance of camera backwards from rocket."},
		{"cg_rocketKillCamUpDist", "Rocket kill camera: distance of camera backwards from rocket."},
		{"cg_scriptIconSize", "Size of Icons defined by script"},
		{"cg_showmiss", "Show prediction errors"},
		{"cg_sprintMeterDisabledColor", "The color of the sprint meter when the sprint meter is full"},
		{"cg_sprintMeterEmptyColor", "The color of the sprint meter when the sprint meter is full"},
		{"cg_sprintMeterFullColor", "The color of the sprint meter when the sprint meter is full"},
		{"cg_subtitleMinTime", "The minimum time that the subtitles are displayed on screen in seconds"},
		{"cg_subtitleWidthStandard", "The width of the subtitles on a non wide-screen"},
		{"cg_subtitleWidthWidescreen", "The width of the subtitle on a wide-screen"},
		{"cg_teamChatsOnly", "Allow chatting only on the same team"},
		{"cg_TeamColor_Allies", "Allies team color"},
		{"cg_TeamColor_Axis", "Axis team color"},
		{"cg_TeamColor_EnemyTeam", "Enemy team color"},
		{"cg_TeamColor_Free", "Free Team color"},
		{"cg_TeamColor_MyParty", "Player team color when in the same party"},
		{"cg_TeamColor_MyTeam", "Player team color"},
		{"cg_TeamColor_Spectator", "Spectator team color"},
		{"cg_turretKillCamBackDist", "Turret kill camera: distance of camera backwards from Turret."},
		{"cg_turretKillCamFov", "Turret kill camera field of view."},
		{"cg_turretKillCamUpDist", "Turret kill camera: distance of camera backwards from Turret."},
		{"cg_turretRemoteKillCamBackDist", "Remote Turret kill camera: distance of camera backwards from Turret."},
		{"cg_turretRemoteKillCamFov", "Remote Turret kill camera field of view."},
		{"cg_turretRemoteKillCamUpDist", "Remote Turret kill camera: distance of camera backwards from Turret."},
		{"cg_vectorFieldsForceUniform", "Forces all vector field assets to represent a single, uniform direction"},
		{"cg_viewVehicleInfluence", "The influence on the view angles from being in a vehicle"},
		{"cg_viewZSmoothingMax", "Threshhold for the maximum smoothing distance we'll do"},
		{"cg_viewZSmoothingMin", "Threshhold for the minimum smoothing distance it must move to smooth"},
		{"cg_viewZSmoothingTime", "Amount of time to spread the smoothing over"},
		{"cg_voiceIconSize", "Size of the 'voice' icon"},
		{"cg_waterSheeting_distortionScaleFactor", "Distortion uv scales (Default to 1)"},
		{"cg_waterSheeting_magnitude", "Distortion magnitude"},
		{"cg_waterSheeting_radius", "Tweak dev var; Glow radius in pixels at 640x480"},
		{"cg_weapHitCullAngle", "Angle of cone within which to cull back facing weapon hit effects"},
		{"cg_weapHitCullEnable", "When true, cull back facing weapon hit fx."},
		{"cg_weaponCycleDelay", "The delay after cycling to a new weapon to prevent holding down the cycle weapon button from cycling too fast"},
		{"cg_weaponHintsCoD1Style", "Draw weapon hints in CoD1 style: with the weapon name, and with the icon below"},
		{"cg_weaponVisInterval", "Do weapon vis checks once per this many frames, per centity"},
		{"cg_youInKillCamSize", "Size of the 'you' Icon in the kill cam"},
		{"cl_anglespeedkey", "Multiplier for max angle speed for game pad and keyboard"},
		{"cl_bypassMouseInput", "Bypass UI mouse input and send directly to the game"},
		{"cl_connectionAttempts", "Maximum number of connection attempts before aborting"},
		{"cl_connectTimeout", "Timeout time in seconds while connecting to a server"},
		{"cl_demo_uploadfb", "Should we upload to FB"},
		{"cl_dirSelConvergenceTime", "Time to converge to the new direction when selecting a direction on the map."},
		{"cl_force_paused", "Force the client to be paused. Can't be overridden by LUA scripts, the start button, etc."},
		{"cl_freelook", "Enable looking with mouse"},
		{"cl_hudDrawsBehindUI", "Should the HUD draw when the UI is up?"},
		{"cl_ingame", "True if the game is active"},
		{"cl_inhibit_stats_upload", "Inhibit upload of stats during demo playback"},
		{"cl_lessprint", "Print less to the console by filtering out certain spammy channels"},
		{"cl_maxpackets", "Maximum number of packets sent per frame"},
		{"cl_maxPing", "Maximum ping for the client"},
		{"cl_migrationTimeout", "Seconds to wait to hear from new host during host migration before timeout occurs"},
		{"cl_modifiedDebugPlacement", "Modify the location of debug output (outside of safe area)"},
		{"cl_motdString", ""},
		{"cl_mouseAccel", "Mouse acceleration"},
		{"cl_noprint", "Print nothing to the console"},
		{"cl_packetdup", "Enable packet duplication"},
		{"cl_pauseAudioZoneEnabled", "Enable the paused audio zone when the menus are up"},
		{"cl_paused", "Pause the game"},
		{"cl_pitchspeed", "Max pitch speed in degrees for game pad"},
		{"cl_pranks", "pranks"},
		{"cl_pushToTalk", "Do we have to press a button to talk"},
		{"cl_serverStatusResendTime", "Time in milliseconds to resend a server status message"},
		{"cl_showmouserate", "Print mouse rate debugging information to the console"},
		{"cl_textChatEnabled", "Do we want to use text chat"},
		{"cl_timeout", "Seconds with no received packets until a timeout occurs"},
		{"cl_voice", "Use voice communications"},
		{"cl_yawspeed", "Max yaw speed in degrees for game pad and keyboard"},
		{"clientSideEffects", "Enable loading _fx.gsc files on the client"},
		{"cod_anywhere_errorMessage", "CoD Anywhere error message"},
		{"cod_anywhere_showPopup", "Temp Development: Should we show the CoD Anywhere popup"},
		{"cod_anywhere_single_task_popup_text", "CoD Anywhere success message"},
		{"com_animCheck", "Check anim tree"},
		{"com_cinematicEndInWhite", "Set by script. True if cinematic ends with a white screen."},
		{"com_completionResolveCommand", "Command to run when the message box successfully closes"},
		{"com_errorMessage", "Most recent error message"},
		{"com_errorResolveCommand", "Command to run when they close the error box"},
		{"com_filter_output", "Use console filters for filtering output."},
		{"com_maxfps", "Cap frames per second"},
		{"com_maxFrameTime", "Time slows down if a frame takes longer than this many milliseconds"},
		{"com_playerProfile", "Set to the name of the profile"},
		{"com_recommendedSet", ""},
		{"commerce_dl_retry_step", "Step in m/s for the commerce download retry"},
		{"commerce_manifest_file_max_retry_time", "Max time that the commerce manifest can retry"},
		{"commerce_manifest_file_retry_step", "Step in m/s for the commerce manifest retry"},
		{"commerce_max_dl_retry_time", "Max time that the commerce download can retry"},
		{"commerce_max_retry_time", "Max time that the commerce upload can retry"},
		{"commerce_retry_step", "Step in m/s for the commerce upload retry"},
		{"compass", "Display Compass"},
		{"compassClampIcons", "If true, friendlies and enemy pings clamp to the edge of the radar.  If false, they disappear off the edge."},
		{"compassCoords", "x = North-South coord base value, \ny = East-West coord base value, \nz = scale (game units per coord unit)"},
		{"compassECoordCutoff", "Left cutoff for the scrolling east-west coords"},
		{"compassFriendlyHeight", ""},
		{"compassFriendlyWidth", ""},
		{"compassHideSansObjectivePointer", "Hide the compass, but leave the obective pointer visible."},
		{"compassHideVehicles", "When enabled, disables the CG_PLAYER_COMPASS_VEHICLES ownerdraw."},
		{"compassMaxRange", "The maximum range from the player in world space that objects will be shown on the compass"},
		{"compassMinRadius", "The minimum radius from the center of the compass that objects will appear."},
		{"compassMinRange", "The minimum range from the player in world space that objects will appear on the compass"},
		{"compassObjectiveArrowHeight", ""},
		{"compassObjectiveArrowOffset", "The offset of the objective arrow inward from the edge of the compass map"},
		{"compassObjectiveArrowRotateDist", "Distance from the corner of the compass map at which the objective arrow rotates to 45 degrees"},
		{"compassObjectiveArrowWidth", ""},
		{"compassObjectiveDetailDist", "When an objective is closer than this distance (in meters), the icon will not be drawn on the tickertape."},
		{"compassObjectiveDrawLines", "Draw horizontal and vertical lines to the active target, if it is within the minimap boundries"},
		{"compassObjectiveHeight", ""},
		{"compassObjectiveIconHeight", ""},
		{"compassObjectiveIconWidth", ""},
		{"compassObjectiveMaxHeight", "The maximum height that an objective is considered to be on this level"},
		{"compassObjectiveMaxRange", "The maximum range at which an objective is visible on the compass"},
		{"compassObjectiveMinAlpha", "The minimum alpha for an objective at the edge of the compass"},
		{"compassObjectiveMinDistRange", "The distance that objective transition effects play over, centered on compassObjectiveNearbyDist."},
		{"compassObjectiveMinHeight", "The minimum height that an objective is considered to be on this level"},
		{"compassObjectiveNearbyDist", "When an objective is closer than this distance (in meters), the icon will not be drawn on the tickertape."},
		{"compassObjectiveNumRings", "The number of rings when a new objective appears"},
		{"compassObjectiveRingSize", "The maximum objective ring sige when a new objective appears on the compass"},
		{"compassObjectiveRingTime", "The amount of time between each ring when an objective appears"},
		{"compassObjectiveTextHeight", "Objective text height"},
		{"compassObjectiveTextScale", "Scale to apply to hud objectives"},
		{"compassObjectiveWidth", ""},
		{"compassObjectiveWraparoundTime", "How long it takes for the objective to wrap around the compass from one edge to the other"},
		{"compassPlayerHeight", ""},
		{"compassPlayerWidth", ""},
		{"compassRadarLineThickness", "Thickness, relative to the compass size, of the radar texture that sweeps across the map"},
		{"compassRadarPingFadeTime", "How long an enemy is visible on the compass after it is detected by radar"},
		{"compassRotation", "Style of compass"},
		{"compassSize", "Scale the compass"},
		{"compassSoundPingFadeTime", "The time in seconds for the sound overlay on the compass to fade"},
		{"compassTickertapeStretch", "How far the tickertape should stretch from its center."},
		{"comscore_active", "Are we allowed to enable ComScore tracking or not"},
		{"con_gameMsgWindow0FadeInTime", ""},
		{"con_gameMsgWindow0FadeOutTime", ""},
		{"con_gameMsgWindow0Filter", ""},
		{"con_gameMsgWindow0LineCount", ""},
		{"con_gameMsgWindow0MsgTime", ""},
		{"con_gameMsgWindow0ScrollTime", ""},
		{"con_gameMsgWindow1FadeInTime", ""},
		{"con_gameMsgWindow1FadeOutTime", ""},
		{"con_gameMsgWindow1Filter", ""},
		{"con_gameMsgWindow1LineCount", ""},
		{"con_gameMsgWindow1MsgTime", ""},
		{"con_gameMsgWindow1ScrollTime", ""},
		{"con_gameMsgWindow2FadeInTime", ""},
		{"con_gameMsgWindow2FadeOutTime", ""},
		{"con_gameMsgWindow2Filter", ""},
		{"con_gameMsgWindow2LineCount", ""},
		{"con_gameMsgWindow2MsgTime", ""},
		{"con_gameMsgWindow2ScrollTime", ""},
		{"con_gameMsgWindow3FadeInTime", ""},
		{"con_gameMsgWindow3FadeOutTime", ""},
		{"con_gameMsgWindow3Filter", ""},
		{"con_gameMsgWindow3LineCount", ""},
		{"con_gameMsgWindow3MsgTime", ""},
		{"con_gameMsgWindow3ScrollTime", ""},
		{"con_subtitleLeading", "Leading for subtitles, calculated as a percentage of the font height"},
		{"con_typewriterColorGlowCheckpoint", ""},
		{"con_typewriterColorGlowCompleted", ""},
		{"con_typewriterColorGlowFailed", ""},
		{"con_typewriterColorGlowUpdated", ""},
		{"con_typewriterColorInteriorCheckpoint", ""},
		{"con_typewriterColorInteriorCompleted", ""},
		{"con_typewriterColorInteriorFailed", ""},
		{"con_typewriterColorInteriorUpdated", ""},
		{"con_typewriterDecayDuration", "Time (in milliseconds) to spend disolving the line away."},
		{"con_typewriterDecayStartTime", "Time (in milliseconds) to spend between the build and disolve phases."},
		{"con_typewriterPrintSpeed", "Time (in milliseconds) to print each letter in the line."},
		{"counterDownloadInterval", "Number of minutes before all the global counters are uploaded"},
		{"counterUploadInterval", "Number of minutes before all the global counters are uploaded"},
		{"cpu_speed_12players", "12 player sys_configureGHz req'd"},
		{"cpu_speed_18players", "18 player sys_configureGHz req'd"},
		{"cpu_speed_8players", "8 player sys_configureGHz req'd"},
		{"cSplineDebugRender", "Debug Render the csplines."},
		{"cSplineDebugRenderCorridor", "Debug Render the cspline corridor."},
		{"cSplineDebugRenderData", "Debug Render the cspline data."},
		{"cSplineDebugRenderSplineId", "Select a cspline - 0 for all."},
		{"dailychallenge_killswitch", "daily challenge killswitch - int with bits used to flag individual daily challenges as enabled"},
		{"dailychallenge_killswitch2", "daily challenge killswitch2 - int with bits used to flag 2nd set of individual daily challenges as enabled"},
		{"dailychallenge_period", "daily challenge period - utc value for a day"},
		{"data_validation_allow_drop", ""},
		{"dc_lobbymerge", "Allows lobby merging across data centres"},
		{"dcacheSimulateNoHDD", "When turned on, simulate no HDD for caching."},
		{"dcacheThrottleEnabled", "Enable or disable dcache upload throttling."},
		{"dcacheThrottleKBytesPerSec", "Dcache upload throttle limit in K Bytes per second."},
		{"dedicated_dhclient", "True if we're a client playing on a DH server"},
		{"demonwareConsideredConnectedTime", "Number of milliseconds after being disconnected from demonware before considering shutting down."},
		{"developer", "Enable development options"},
		{"didyouknow", ""},
		{"discard_playerstats_on_suspend", "Forces stats discard on suspend"},
		{"drawEntityCount", "Enable entity count drawing"},
		{"drawEntityCountPos", "Where to draw the entity count graph"},
		{"drawEntityCountSize", "undefined"},
		{"drawKillcamData", "Enable drawing server killcam data"},
		{"drawKillcamDataPos", "Where to draw the server killcam graph"},
		{"drawKillcamDataSize", "How big to draw the killcam data graph"},
		{"drawServerBandwidth", "Enable drawing server bandwidth"},
		{"drawServerBandwidthPos", "Where to draw the server bandwidth graph"},
		{"ds_dcid", "optional datacenter id - from playlist"},
		{"ds_dcid_override", "force datacenter id"},
		{"ds_info", "ds info string"},
		{"ds_info_enable", "Enable ds info string"},
		{"ds_introRequestTimeout", "ds intro request timeout (ms)"},
		{"ds_keepaliveInterval", "ds keepalive interval (ms)"},
		{"ds_keepaliveTimeout", "ds keepalive timeout (ms)"},
		{"ds_pingclient_max_reping_distance", "don't re-ping a datacenter if it's further away than this (miles)"},
		{"ds_pingclient_max_repings", "max # of times to re-ping a datacenter"},
		{"ds_pingclient_maxpings", "max pings to send per datacenter"},
		{"ds_pingclient_maxpings_per_tick", "max new pings each tick"},
		{"ds_pingclient_min_reping_delay", "min msec delay between re-pings"},
		{"ds_pingclient_min_reping_latency", "don't re-ping a datacenter if latency is less than this"},
		{"ds_pingclient_minpings", "min responses required per datacenter"},
		{"ds_pingclient_odsf", "does dsping set odsf flag"},
		{"dsping_dc_0", ""},
		{"dsping_dc_1", ""},
		{"dsping_dc_10", ""},
		{"dsping_dc_11", ""},
		{"dsping_dc_12", ""},
		{"dsping_dc_13", ""},
		{"dsping_dc_14", ""},
		{"dsping_dc_15", ""},
		{"dsping_dc_16", ""},
		{"dsping_dc_17", ""},
		{"dsping_dc_18", ""},
		{"dsping_dc_19", ""},
		{"dsping_dc_2", ""},
		{"dsping_dc_20", ""},
		{"dsping_dc_21", ""},
		{"dsping_dc_22", ""},
		{"dsping_dc_23", ""},
		{"dsping_dc_24", ""},
		{"dsping_dc_25", ""},
		{"dsping_dc_26", ""},
		{"dsping_dc_27", ""},
		{"dsping_dc_28", ""},
		{"dsping_dc_29", ""},
		{"dsping_dc_3", ""},
		{"dsping_dc_30", ""},
		{"dsping_dc_31", ""},
		{"dsping_dc_32", ""},
		{"dsping_dc_33", ""},
		{"dsping_dc_34", ""},
		{"dsping_dc_35", ""},
		{"dsping_dc_36", ""},
		{"dsping_dc_37", ""},
		{"dsping_dc_38", ""},
		{"dsping_dc_39", ""},
		{"dsping_dc_4", ""},
		{"dsping_dc_40", ""},
		{"dsping_dc_41", ""},
		{"dsping_dc_42", ""},
		{"dsping_dc_43", ""},
		{"dsping_dc_44", ""},
		{"dsping_dc_45", ""},
		{"dsping_dc_46", ""},
		{"dsping_dc_47", ""},
		{"dsping_dc_48", ""},
		{"dsping_dc_49", ""},
		{"dsping_dc_5", ""},
		{"dsping_dc_50", ""},
		{"dsping_dc_51", ""},
		{"dsping_dc_52", ""},
		{"dsping_dc_53", ""},
		{"dsping_dc_54", ""},
		{"dsping_dc_55", ""},
		{"dsping_dc_56", ""},
		{"dsping_dc_57", ""},
		{"dsping_dc_58", ""},
		{"dsping_dc_59", ""},
		{"dsping_dc_6", ""},
		{"dsping_dc_60", ""},
		{"dsping_dc_61", ""},
		{"dsping_dc_62", ""},
		{"dsping_dc_63", ""},
		{"dsping_dc_7", ""},
		{"dsping_dc_8", ""},
		{"dsping_dc_9", ""},
		{"dvl", "Enables the data validation system. Only available in non-retail builds."},
		{"dw_addrHandleTimeout", "Delay before destroying an addrHandle after the connection is lost\n"},
		{"dw_leaderboard_write_active", "Are leaderboard writes enabled"},
		{"dw_presence_active", "Is the demonware presence system enabled"},
		{"dw_presence_coop_join_active", "Do we allow players to join on presence for private coop matches (post session to demonware"},
		{"dw_presence_get_delay", "Number of milliseconds to wait after booting the game to fetch demonware presence"},
		{"dw_presence_get_rate", "Number of milliseconds to wait between sending presence state to demonware"},
		{"dw_presence_put_delay", "Number of milliseconds to wait in a presence state before sending to demonware"},
		{"dw_presence_put_rate", "Number of milliseconds to wait between sending presence state to demonware"},
		{"dw_region_lookup_timeout", "Timeout (in MS) after which we will accept not having found a region code and use the default"},
		{"dw_shared_presence_active", "Is the demonware shared presence system enabled"},
		{"dw_shared_presence_get_delay", "Number of milliseconds to wait after booting the game to fetch demonware presence"},
		{"dw_shared_presence_get_rate", "Number of milliseconds to wait between sending presence state to demonware"},
		{"dw_shared_presence_put_delay", "Number of milliseconds to wait in a shared presence state before sending to demonware"},
		{"dw_shared_presence_put_rate", "Number of milliseconds to wait between sending presence state to demonware"},
		{"dwBandwidthTestTaskTimeout", "default timeout for the bandwidth test task (in ms). 0 means no timeout"},
		{"dynEnt_active", "Disable/enable dynent reactions"},
		{"dynEnt_playerWakeUpRadius", "Determines threshold distance from player within which all dynents are woken up."},
		{"dynEnt_playerWakeUpZOffset", "Determines vertical distance from player's feet from which wake up sphere is centered."},
		{"elite_clan_active", "Are we allowed to show Elite Clans or not"},
		{"elite_clan_cool_off_time", "Cool off time between calls to fetch the elite clan"},
		{"elite_clan_delay", "Delay before the bdTeams calls start to Demonware. -1 means On-Demand and it will wait until the 'starteliteclan' menu call"},
		{"elite_clan_division_icon_active", "Are we allowed to show Elite Clan division icon or not"},
		{"elite_clan_get_blob_profile_max_retry_time", "Max time that the Elite Clan get private profile can retry"},
		{"elite_clan_get_blob_profile_retry_step", "Step in m/s for the Elite Clan get private profile retry"},
		{"elite_clan_get_clan_max_retry_time", "Max time that the Elite Clan get clan can retry"},
		{"elite_clan_get_clan_retry_step", "Step in m/s for the Elite Clan get clan retry"},
		{"elite_clan_get_members_max_retry_time", "Max time that the Elite Clan get members can retry"},
		{"elite_clan_get_members_retry_step", "Step in m/s for the Elite Clan get members retry"},
		{"elite_clan_get_private_member_profile_max_retry_time", "Max time that the Elite Clan get private profile can retry"},
		{"elite_clan_get_private_member_profile_retry_step", "Step in m/s for the Elite Clan get private profile retry"},
		{"elite_clan_get_public_profile_max_retry_time", "Max time that the Elite Clan get public profile can retry"},
		{"elite_clan_get_public_profile_retry_step", "Step in m/s for the Elite Clan get public profile retry"},
		{"elite_clan_get_team_stats_max_retry_time", "Max time that the Elite Clan get team stats can retry"},
		{"elite_clan_get_team_stats_retry_step", "Step in m/s for the Elite Clan get team stats retry"},
		{"elite_clan_motd_throttle_time", "Throttle time between motd update calls"},
		{"elite_clan_remote_view_active", "Are we allowed to view the clans for remote players"},
		{"elite_clan_remote_view_max_retry_time", "Max time that the Elite Clan remote viewing can retry"},
		{"elite_clan_remote_view_retry_step", "Step in m/s for the retry for viewing a remote Elite Clan"},
		{"elite_clan_send_message_to_members_max_retry_time", "Max time that the Elite Clan send message to members can retry"},
		{"elite_clan_send_message_to_members_retry_step", "Step in m/s for the Elite Clan send message to members retry"},
		{"elite_clan_set_private_member_profile_max_retry_time", "Max time that the Elite Clan set private member profile can retry"},
		{"elite_clan_set_private_member_profile_retry_step", "Step in m/s for the Elite Clan set private member profile retry"},
		{"elite_clan_single_task_popup_text", "String to be displayed on popup when a single task is being performed"},
		{"elite_clan_using_title", "Stores whether the Elite Clan title is in use by the user"},
		{"emblems_active", "Are we allowed to enable Emblems or not"},
		{"enable_recordRecentActivity", "records the timestamp of when the player was recently active to the tracker leaderboards"},
		{"enableReportingRegisteredParties", "If true then party membership data and host status will be reported in matchdata blob."},
		{"entitlements_active", "Are we allowed to show Entitlements or not"},
		{"entitlements_config_file_max_retry_time", "Max time that the Entitlements config file read can retry"},
		{"entitlements_config_file_retry_step", "Step in m/s for the Entitlements config file read retry"},
		{"entitlements_cool_off_time", "Cool off time between calls to fetch the elite clan"},
		{"entitlements_delay", "Delay before the entitlement calls start to Demonware. -1 means On-Demand and it will wait until the 'startentitlements' menu call"},
		{"entitlements_key_archive_max_retry_time", "Max time that the Entitlements key archive read can retry"},
		{"entitlements_key_archive_retry_step", "Step in m/s for the Entitlements key archive read retry"},
		{"entitlementSystemOk", "Set by the game to inform that the entitlement system is initialised"},
		{"facebook_active", "Are we allowed to show Facebook or not"},
		{"facebook_delay", "Delay before the Facebook calls start to Demonware. -1 means On-Demand and it will wait until the 'startfacebook' menu call"},
		{"facebook_friends_active", "Are we allowed to show Facebook Friends or not"},
		{"facebook_friends_max_retry_time", "Max time that the Facebook friends read can retry"},
		{"facebook_friends_refresh_time", "Time in seconds between Facebook friend refreshes"},
		{"facebook_friends_retry_step", "Step in m/s for the Facebook friends read retry"},
		{"facebook_friends_showing_count", "Contains how many facebook friends are being shown in the UI."},
		{"facebook_friends_throttle_time", "Throttle time between Facebook friend pages"},
		{"facebook_max_retry_time", "Max time that the Facebook authentication can retry"},
		{"facebook_password", "Facebook Password"},
		{"facebook_password_asterisk", "Facebook Password (Asterisk Version)"},
		{"facebook_popup_text", "Facebook Popup Text"},
		{"facebook_retry_step", "Step in m/s for the Facebook authentication retry"},
		{"facebook_upload_photo_active", "Are we allowed to Upload Photos to  Facebook or not"},
		{"facebook_upload_video_active", "Are we allowed to Upload Videos to Facebook or not"},
		{"facebook_username", "Facebook Username"},
		{"fixedtime", "Use a fixed time rate for each frame"},
		{"FoFIconMaxSize", "Maximum size a Friend-or-Foe icon should ever grow to."},
		{"FoFIconMinSize", "Minimum size a Friend-or-Foe icon should ever shrink to."},
		{"FoFIconScale", "Base scale of Friend-or-Foe icons."},
		{"FoFIconSpawnTimeDelay", "How long to wait, after spawning, before showing the Friend-or-Foe icon on a player."},
		{"FoFIconSpawnTimeFade", "Length of the Friend-or-Foe icons' fade-ins."},
		{"friendsCacheSteamFriends", "Use cache of steam friends before querying steam api"},
		{"friendsMaxSteamLookupsPerFrame", "Number of steam friends to query steam status per frame when doing a refresh.\n"},
		{"friendsWidgetMinimumRefreshTimer", "Minimum delay before refreshing friends data if you aren't on the friends screen\n"},
		{"fs_basegame", "Base game name"},
		{"fs_basepath", "Base game path"},
		{"fs_basepath_output", "Base game path"},
		{"fs_cdpath", "CD path"},
		{"fs_copyfiles", "Copy all used files to another location"},
		{"fs_debug", "Enable file system debugging information"},
		{"fs_game", "Game data directory. Must be \"\" or a sub directory of 'mods/'."},
		{"fs_homepath", "Game home path"},
		{"fs_ignoreLocalized", "Ignore localized assets"},
		{"fx_alphaThreshold", "Don't draw billboard sprites, oriented sprites or tails with alpha below this threshold (0-256)."},
		{"fx_cast_shadow", "Enable transparency shadow mapping from script"},
		{"fx_count", "Debug effects count"},
		{"fx_cull_elem_draw", "Culls effect elems for drawing"},
		{"fx_cull_elem_draw_flicker", "Flicker DPVS culled effect elems"},
		{"fx_cull_elem_spawn", "Culls effect elems for spawning"},
		{"fx_debugBolt", "Debug effects bolt"},
		{"fx_deferelem", "Toggles deferred processing of elements instead of effects"},
		{"fx_dpvs_cull_elem_draw", "Culls effect elems for drawing using DPVS(2: ignore per-effect portal culling flag)"},
		{"fx_draw", ""},
		{"fx_draw_omniLight", ""},
		{"fx_draw_simd", "Draw effects using SIMD / Vector code."},
		{"fx_draw_spotLight", ""},
		{"fx_drawClouds", "Toggles the drawing of particle clouds"},
		{"fx_enable", "Toggles all effects processing"},
		{"fx_flare", "Toggles fx flare"},
		{"fx_freeze", "Freeze effects"},
		{"fx_killEffectOnRewind", "Causes effects that have been marked for a soft kill (fade out) to be killed immediately on a rewind."},
		{"fx_lightGridSampleOffset", "the length of effect sample's offset along X Axis"},
		{"fx_mark_profile", "Turn on FX profiling for marks (specify which local client, with '1' being the first.)"},
		{"fx_marks", "Toggles whether bullet hits leave marks"},
		{"fx_marks_ents", "Toggles whether bullet hits leave marks"},
		{"fx_marks_nearlimit", "Sets limit of number of decals that can exist at the same location (0 for unlimited)"},
		{"fx_marks_smodels", "Toggles whether bullet hits leave marks"},
		{"fx_physicsImpactVelocityThreshold", "Set the min normal velocity threshold in order for model physics fx to generate child impact effects."},
		{"fx_profile", "Turn on FX profiling (specify which local client, with '1' being the first.)"},
		{"fx_profileFilter", "Only show effects with this as a substring in FX profile"},
		{"fx_profileFilterElemCountZero", "Do not include FX that have a zero element count"},
		{"fx_profileSkip", "Skip the first n lines in FX profile (to see ones off bottom of screen)"},
		{"fx_profileSort", "Choose sort criteria for FX profiling"},
		{"fx_showLightGridSampleOffset", "show light grid sample offset in CreateFX mode"},
		{"fx_visMinTraceDist", "Minimum visibility trace size"},
		{"g_allowVote", "Enable voting on this server"},
		{"g_atmosFogDistanceScaleReadOnly", "scale applied to scene distance used for atmospheric fog calculation"},
		{"g_atmosFogEnabledReadOnly", "use atmospheric fog"},
		{"g_atmosFogExtinctionStrengthReadOnly", "scale out scatter contribution of atmospheric fog"},
		{"g_atmosFogHalfPlaneDistanceReadOnly", "distance at which atmospheric fog contributes half the pixels color"},
		{"g_atmosFogHazeSpreadReadOnly", "directionality of haze (1ReadOnly = all forward scatter, 0ReadOnly = all back scatter)"},
		{"g_atmosFogHazeStrengthReadOnly", "portion of atmospheric fog density that is haze (0ReadOnly = all fog, 1ReadOnly = all haze)"},
		{"g_atmosFogHeightFogBaseHeightReadOnly", "height fog is full density at this world height and below"},
		{"g_atmosFogHeightFogEnabledReadOnly", "use height for atmospheric fog"},
		{"g_atmosFogHeightFogHalfPlaneDistanceReadOnly", "at this distance above g_atmosFogHeightFogBaseHeight, height fog density is half"},
		{"g_atmosFogInScatterStrengthReadOnly", "scale in scatter contribution of atmospheric fog"},
		{"g_atmosFogSkyAngularFalloffEnabledReadOnly", "use angular sky falloff for atmospheric fog"},
		{"g_atmosFogSkyDistanceReadOnly", "distance used for sky box when applying atmospheric fog"},
		{"g_atmosFogSkyFalloffAngleRangeReadOnly", "sky fog angular falloff angle range sky fog falls off over this range from the start angle"},
		{"g_atmosFogSkyFalloffStartAngleReadOnly", "sky fog angular falloff start angle (full strength fog at this angle)"},
		{"g_atmosFogStartDistanceReadOnly", "distance from camera at which fog contribution begins"},
		{"g_atmosFogSunDirectionReadOnly", "sun direction used when calculating atmospheric fog"},
		{"g_banIPs", "IP addresses to ban from playing"},
		{"g_clonePlayerMaxVelocity", "Maximum velocity in each axis of a cloned player\n(for death animations)"},
		{"g_deadChat", "Allow dead players to chat with living players"},
		{"g_dropForwardSpeed", "Forward speed of a dropped item"},
		{"g_dropHorzSpeedRand", "Random component of the initial horizontal speed of a dropped item"},
		{"g_dropUpSpeedBase", "Base component of the initial vertical speed of a dropped item"},
		{"g_dropUpSpeedRand", "Random component of the initial vertical speed of a dropped item"},
		{"g_earthquakeEnable", "Enable camera shake"},
		{"g_fogColorIntensityReadOnly", "HDR fog color intensity that was set in the most recent call to \"setexpfog\""},
		{"g_fogColorReadOnly", "Fog color that was set in the most recent call to \"setexpfog\""},
		{"g_fogHalfDistReadOnly", ""},
		{"g_fogMaxOpacityReadOnly", "Fog max opacity that was set in the most recent call to \"setexpfog\""},
		{"g_fogStartDistReadOnly", ""},
		{"g_friendlyfireDist", "Maximum range for disabling fire at a friendly"},
		{"g_friendlyNameDist", "Maximum range for seeing a friendly's name"},
		{"g_gametype", "The current game mode"},
		{"g_giveAll", "Give all weapons"},
		{"g_hardcore", "Hardcore?"},
		{"g_heightFogBaseHeightReadOnly", "height fog is full density at this world height and below"},
		{"g_heightFogEnabledReadOnly", "use height for normal/sun fog, set in the most recent call to \"setexpfog\""},
		{"g_heightFogHalfPlaneDistanceReadOnly", "at this distance above g_heightFogBaseHeight, height fog density is half, set in the most recent call to \"setexpfog\""},
		{"g_inactivity", "Time delay before player is kicked for inactivity"},
		{"g_keyboarduseholdtime", "The time to hold down the 'use' button to activate a 'use' command on a keyboard"},
		{"g_knockback", "Maximum knockback"},
		{"g_lagged_damage_threshold", "Threshold (ms) beyond which we will report a damaged lagged client to the tracker leaderboards."},
		{"g_listEntity", "List the entities"},
		{"g_mantleBlockTimeBuffer", "Time that the client think is delayed after mantling"},
		{"g_maxDroppedWeapons", "Maximum number of dropped weapons"},
		{"g_minGrenadeDamageSpeed", "Minimum speed at which getting hit be a grenade will do damage (not the grenade explosion damage)"},
		{"g_oldschool", "Oldschool?"},
		{"g_password", "Password"},
		{"g_playerCollisionEjectSpeed", "Speed at which to push intersecting players away from each other"},
		{"g_ScoresColor_Allies", "Allies team color on scoreboard"},
		{"g_ScoresColor_Axis", "Axis team color on scoreboard"},
		{"g_ScoresColor_EnemyTeam", "Enemy team color on scoreboard"},
		{"g_ScoresColor_Free", "Free Team color on scoreboard"},
		{"g_ScoresColor_MyParty", "Player team color on scoreboard when in the same party"},
		{"g_ScoresColor_MyTeam", "Player team color on scoreboard"},
		{"g_ScoresColor_Spectator", "Spectator team color on scoreboard"},
		{"g_scriptMainMenu", ""},
		{"g_sunFogBeginFadeAngleReadOnly", "Angle from the sun direction to start fade away from the sun fog color that was set in the most recent call to \"setexpfog\""},
		{"g_sunFogColorIntensityReadOnly", "HDR sun fog color intensity that was set in the most recent call to \"setexpfog\""},
		{"g_sunFogColorReadOnly", "Sun fog color that was set in the most recent call to \"setexpfog\""},
		{"g_sunFogDirReadOnly", "Sun fog direction that was set in the most recent call to \"setexpfog\""},
		{"g_sunFogEnabledReadOnly", "Sun fog was enabled in the most recent call to \"setexpfog\""},
		{"g_sunFogEndFadeAngleReadOnly", "Angle from the sun direction to end fade away from the sun fog color that was set in the most recent call to \"setexpfog\""},
		{"g_sunFogScaleReadOnly", "Distance scale in the sun fog direction that was set in the most recent call to \"setexpfog\""},
		{"g_TeamIcon_Allies", "Icon name for the allied scores banner"},
		{"g_TeamIcon_Axis", "Icon name for the axis scores banner"},
		{"g_TeamIcon_EnemyAllies", "Icon name for the allied scores banner"},
		{"g_TeamIcon_EnemyAxis", "Icon name for the axis scores banner when you're on axis."},
		{"g_TeamIcon_Free", "Icon name for the scores of players with no team"},
		{"g_TeamIcon_MyAllies", "Icon name for the allied scores banner"},
		{"g_TeamIcon_MyAxis", "Icon name for the axis scores banner when you're on axis."},
		{"g_TeamIcon_Spectator", "Icon name for the scores of players who are spectators"},
		{"g_TeamName_Allies", "Allied team name"},
		{"g_TeamName_Axis", "Axis team name"},
		{"g_TeamTitleColor_EnemyTeam", "Enemy team color for titles"},
		{"g_TeamTitleColor_MyTeam", "Player team color for titles"},
		{"g_TeamTitleColor_Spectator", "Spectator team color for titles"},
		{"g_useholdspawndelay", "Time in milliseconds that the player is unable to 'use' after spawning"},
		{"g_useholdtime", "Time to hold the 'use' button to activate use on a gamepad"},
		{"g_voiceChatTalkingDuration", "Time after the last talk packet was received that the player is considered by the\nserver to still be talking in milliseconds"},
		{"gamedate", "The date compiled"},
		{"gamedvr_active", "Are we allowed to enable GameDVR or not"},
		{"gameMode", "Current gameMode"},
		{"gamename", "The name of the game"},
		{"glass_angular_vel", "Sets the range of angular velocities used by new glass pieces"},
		{"glass_beamDamage", "The amount of damage beam attacks do to glass"},
		{"glass_break", "Toggle whether or not glass breaks when shot"},
		{"glass_crack_pattern_scale", "The scale applied to the radius used for the crack pattern"},
		{"glass_damageToDestroy", "The amount of damage a piece of glass must take to look damaged"},
		{"glass_damageToWeaken", "The amount of damage a piece of glass must take to look damaged"},
		{"glass_edge_angle", "Sets the range of angle deflections used by new glass pieces on a supported edge"},
		{"glass_fall_delay", "Sets how long a heavy piece supported by a single edge waits before falling, based on glass_fall_ratio"},
		{"glass_fall_gravity", "Gravity for falling pieces of glass"},
		{"glass_fall_ratio", "Ratio of piece area to supporting edge length squared.  Below the min, the piece never falls."},
		{"glass_fringe_maxcoverage", "The maximum portion of the original piece of glass that is allowed to remain after the glass shatters"},
		{"glass_fringe_maxsize", "The maximum area for an edge piece of glass when shattering. Pieces larger than this will be broken into smaller ones"},
		{"glass_fx_chance", "Chance to play an effect on a small piece of glass when it hits the ground"},
		{"glass_hinge_friction", "Friction used by moving glass pieces when joined like a hinge to a frame"},
		{"glass_linear_vel", "Sets the range of linear velocities used by new glass pieces"},
		{"glass_max_pieces_per_frame", "Maximum number of pieces to create in one frame. This is a guideline and not a hard limit."},
		{"glass_max_shatter_fx_per_frame", "Maximum number of shatter effects to play in one frame This is a guideline and not a hard limit."},
		{"glass_meleeDamage", "The amount of damage melee attacks do to glass"},
		{"glass_physics_chance", "The chance for a given shard of glass to use physics"},
		{"glass_physics_maxdist", "The maximum distance of a glass piece from the player to do physics"},
		{"glass_radiusDamageMultiplier", "The amount to scale damage to glass from grenades and other explosions"},
		{"glass_shard_maxsize", "The maximum area for a flying piece of glass when shattering. Pieces larger than this will be broken into smaller ones"},
		{"glass_shattered_scale", "The scale of the shattered glass material"},
		{"glass_trace_interval", "The length of time, in milliseconds, between glass piece traces"},
		{"gpad_button_deadzone", "Game pad button deadzone threshhold"},
		{"gpad_dpadDebounceTime", ""},
		{"gpad_menu_scroll_delay_first", "Menu scroll key-repeat delay, for the first repeat, in milliseconds"},
		{"gpad_menu_scroll_delay_rest_accel", "Menu scroll key-repeat delay acceleration from start to end, for repeats after the first, in milliseconds per repeat"},
		{"gpad_menu_scroll_delay_rest_end", "Menu scroll key-repeat delay end, for repeats after the first, in milliseconds"},
		{"gpad_menu_scroll_delay_rest_start", "Menu scroll key-repeat delay start, for repeats after the first, in milliseconds"},
		{"gpad_stick_deadzone_max", "Game pad maximum stick deadzone"},
		{"gpad_stick_deadzone_min", "Game pad minimum stick deadzone"},
		{"gpad_stick_pressed", "Game pad stick pressed threshhold"},
		{"gpad_stick_pressed_hysteresis", "Game pad stick pressed no-change-zone around gpad_stick_pressed to prevent bouncing"},
		{"groupDownloadInterval", "Minimum interval to wait before getting new group counts"},
		{"groupUploadInterval", "Minimum interval to wait before setting new group counts"},
		{"heli_barrelMaxVelocity", ""},
		{"heli_barrelRotation", "How much to rotate the turret barrel when a helicopter fires"},
		{"heli_barrelSlowdown", ""},
		{"hiDef", "True if the game video is running in high-def."},
		{"httpnetfs", "Stream fastfiles from the specified http server"},
		{"hud_bloodOverlayLerpRate", "Rate at which blood overlay fades out"},
		{"hud_deathQuoteFadeTime", "The time for the death quote to fade"},
		{"hud_drawHud", ""},
		{"hud_enable", "Enable hud elements"},
		{"hud_fade_ammodisplay", "The time for the ammo display to fade in seconds"},
		{"hud_fade_compass", "The time for the compass to fade in seconds"},
		{"hud_fade_healthbar", "The time for the health bar to fade in seconds"},
		{"hud_fade_offhand", "The time for the offhand weapons to fade in seconds"},
		{"hud_fade_sprint", "The time for the sprint meter to fade in seconds"},
		{"hud_flash_period_offhand", "Offhand weapons flash period on changing weapon"},
		{"hud_flash_time_offhand", "Offhand weapons flash duration on changing weapon"},
		{"hud_health_pulserate_critical", "The pulse rate of the 'critical' pulse effect"},
		{"hud_health_pulserate_injured", "The pulse rate of the 'injured' pulse effect"},
		{"hud_health_startpulse_critical", "The health level at which to start the 'injured' pulse effect"},
		{"hud_health_startpulse_injured", "The health level at which to start the 'injured' pulse effect"},
		{"hudElemPausedBrightness", "Brightness of the hudelems when the game is paused."},
		{"hudOutlineDuringADS", "Turn on the HUD outline (green for friendly, red for enemy) when you are pointing at a player while in ADS."},
		{"igs_config_dw_filename", "Name of the configuration file on DW Publisher storage."},
		{"igs_sosp", "Show Original Season Pass"},
		{"igs_td", "Show Trial DLC"},
		{"igs_version", "Version id for the In-game store. Set version number to 0, to disable update."},
		{"in_mouse", "Initialize the mouse drivers"},
		{"inpubliclobby", "Currently in a public lobby"},
		{"intro", "Intro movie should play"},
		{"inventory_addEntitlementsToLocalInventory", "bypass the exchange and directly add entitlements to the local cached player inventory."},
		{"inventory_enabled", "enable/disable the inventory feature"},
		{"inventory_enableEntitlementDLCScanning", "enable scanning of entitlement DLC."},
		{"inventory_enableRevoke", "Enable revoke on purchases you no longer have rights to."},
		{"inventory_exchangeEnabled", "enable/disable the 1st party exchange feature"},
		{"inventory_exchangeMaxConsumablesPerBoot", "The maximum number of the same consumable that can be added per boot."},
		{"inventory_exchangeRetryBaseMS", "The amount to delay with each subsequent retry as base value to be multiplied by an exponential factor 1000 = (1000, 2000, 4000, 8000 etc.)"},
		{"inventory_exchangeRetryByRound", "enable/disable retry with exponential delay one round of exchanges at a time (1, 2, 3, 1, 2, 3, 1, 2, 3 etc.), vs exponential delay per exchange (1, 1, 1, 2, 2, 2, 3, 3, 3 etc.)"},
		{"inventory_exchangeRetryMax", "The number of times to retry for each exchange."},
		{"inventory_excludeEntitlementDLCScanning", "exclude scanning of entitlement DLC (comma separated list of ids to exclude)."},
		{"inventory_ignoreDWPushNotification_claimAchievement", "ignore incoming push notifications from DW to signal item update"},
		{"inventory_ignoreDWPushNotification_itemUpdate", "ignore incoming push notifications from DW to signal item update"},
		{"inventory_taskDefaultTimeout", "default timeout for inventory tasks (in seconds)"},
		{"inventory_taskExchangeTimeout", "default timeout for inventory exchange tasks (in seconds)"},
		{"inventory_taskGetTimeout", "default timeout for inventory GET tasks (in seconds)"},
		{"inventory_triggerExchangeOnContentMount", "trigger an exchange after mounting new content packs"},
		{"inventory_triggerExchangeOnStoreExit", "trigger an exchange when exiting the store"},
		{"iotd_active", "Is the IOTD system enabled"},
		{"iotd_retry", "Can the IOTD system retry fetching data from Demonware"},
		{"jump_slowdownEnable", "Slow player movement after jumping"},
		{"laserDebug", "Enables the display of various debug info."},
		{"laserLightRadius", "undefined"},
		{"laserRadius", "undefined"},
		{"lb_filter", "Filter applied to the leaderboard display: ('none','friends','facebook_friends')"},
		{"lb_group", "GroupID applied to the leaderboard display"},
		{"lb_maxrows", "Maximum number of rows to fetch"},
		{"lb_minrefresh", "Minimum time (in seconds) between leaderboard fetches"},
		{"lb_readDelay", "Delay time between reads(in milliseconds) between leaderboard fetches"},
		{"lb_throttle_time", "Lobby throttling amount"},
		{"lb_times_in_window", "Lobby throttling window amount"},
		{"lb_window", "Lobby throttling window"},
		{"live_qosec_firstupdatems", "MS to wait before deciding to early out qos"},
		{"live_qosec_lastupdatems", "MS since last update required to early out qos"},
		{"live_qosec_minpercent", "Minimum percentage of probe results required before early outing qos"},
		{"live_qosec_minprobes", "Minimum probe results required before early outing qos"},
		{"liveanticheatunknowndvar", "Live Anti Cheat Unknown Dvar"},
		{"livestreaming_active", "Are we allowed to enable LiveStreaming or not"},
		{"loading_sre_fatal", "Loading errors prevent level from loading."},
		{"lobby_animationSpeed", "How long each frame of the animation should draw, in milliseconds"},
		{"lobby_animationTilesHigh", "How many animation tiles high is the searching_for_player texture"},
		{"lobby_animationTilesWide", "How many animation tiles wide is the searching_for_player texture"},
		{"lobby_numAnimationFrames", "How many animation tiles are in the searching_for_player texture"},
		{"lobby_searchingPartyColor", "The color to show that we're searching for that slot when shown in lobbies"},
		{"loc_language", "Language"},
		{"loc_translate", "Enable translations"},
		{"log_host_migration_chance", "The % chance of host migration results telemetry"},
		{"log_party_state", "Log party state updates to Black Box system"},
		{"lowAmmoWarningColor1", "Color 1 of 2 to oscilate between"},
		{"lowAmmoWarningColor2", "Color 2 of 2 to oscilate between"},
		{"lowAmmoWarningNoAmmoColor1", "Like lowAmmoWarningColor1, but when no ammo."},
		{"lowAmmoWarningNoAmmoColor2", "lowAmmoWarningColor2, but when no ammo."},
		{"lowAmmoWarningNoReloadColor1", "Like lowAmmoWarningColor1, but when no ammo."},
		{"lowAmmoWarningNoReloadColor2", "lowAmmoWarningColor2, but when no ammo."},
		{"lowAmmoWarningPulseFreq", "Frequency of the pulse (oscilation between the 2 colors)"},
		{"lowAmmoWarningPulseMax", "Min of oscilation range: 0 is color1 and 1.0 is color2.  Can be < 0, and the wave will clip at 0."},
		{"lowAmmoWarningPulseMin", "Max of oscilation range: 0 is color1 and 1.0 is color2.  Can be > 1.0, and the wave will clip at 1.0."},
		{"lsp_enumertion_max_retry_time", "Max time that the LSP enumeration can retry"},
		{"lsp_enumertion_retry_step", "Step in m/s for the LSP enumeration retry"},
		{"lui_demoMode", "Check if the game is in demo mode."},
		{"lui_FFotDSupportEnabled", "Enables lui to update itself via the ffotd"},
		{"lui_hud_motion_angle_ease_speed", "Hud motion ease percentage of degrees per second"},
		{"lui_hud_motion_bob_scale", "Hud motion bob scale"},
		{"lui_hud_motion_enabled", "Enable hud motion"},
		{"lui_hud_motion_perspective", "value for hud motion perspective transform in pixels"},
		{"lui_hud_motion_rotation_max", "Hud motion rotation max"},
		{"lui_hud_motion_rotation_scale", "Hud motion rotation scale"},
		{"lui_hud_motion_trans_ease_speed", "Hud motion ease percentage of pixels per second"},
		{"lui_hud_motion_translation_max", "Hud motion translation max"},
		{"lui_hud_motion_translation_scale", "Hud motion translation scale"},
		{"lui_loot_duplicateredemption", "Whether a user can redeem duplicate loot items in the Armory"},
		{"LUI_MemErrorsFatal", "Out of memory errors cause drops when true, reinits the UI system if false"},
		{"lui_menuFlowEnabled", "Enables LUI menu flow"},
		{"lui_mlg_rules_unlocked", "Whether MLG rules are unlocked"},
		{"lui_priv_lobby_team", "Team selected in private match lobby"},
		{"lui_splitscreensignin_menu", "Enables the LUI splitscreensignin menu"},
		{"lui_splitscreenupscaling", "Force splitscreen upscaling off/on (-1 off, 1 on) -- requires map change"},
		{"lui_systemlink_menu", "Enables the LUI systemlink menu"},
		{"lui_waitingforgavelmessagesconfirmed", ""},
		{"lui_waitingfornetworktype", "value is LuiWaitingForNetworkType enum"},
		{"lui_waitingforonlinedatafetch_controller", "the controller index that is fetching the online stats data"},
		{"LUI_WorkerCmdGC", "Dev-only flag to enable/disable LUI workerCmd GC thread"},
		{"lui_xboxlive_menu", "Enables the LUI xboxlive menu"},
		{"m_filter", "Allow mouse movement smoothing"},
		{"m_forward", "Forward speed in units per second"},
		{"m_pitch", "Default pitch"},
		{"m_side", "Sideways motion in units per second"},
		{"m_yaw", "Default yaw"},
		{"manifestfs", "Use a manifest file to read segmented fastfiles"},
		{"mapname", "The current map name"},
		{"mapPackMPGroupFourFlags", "Map pack flags that comprise MP ala carte map pack 1"},
		{"mapPackMPGroupFreeFlags", "Map pack flags that comprise the free MP ala carte map pack"},
		{"mapPackMPGroupOneFlags", "Map pack flags that comprise MP ala carte map pack 1"},
		{"mapPackMPGroupThreeFlags", "Map pack flags that comprise MP ala carte map pack 1"},
		{"mapPackMPGroupTwoFlags", "Map pack flags that comprise MP ala carte map pack 1"},
		{"marketing_active", "Are we allowed to enable Marketing Comms or not"},
		{"marketing_refresh_time", "time in seconds to wait before refreshing marketing messages from demonware"},
		{"matchdata_active", "Are match data uploads enabled"},
		{"matchdata_maxcompressionbuffer", "Max SP match data compression buffer to use (in bytes)"},
		{"matchmaking_debug", "Enable matchmaking debugging information"},
		{"max_ping_threshold_good", "max ping value to be considered as good"},
		{"max_ping_threshold_medium", "max ping value to be considered as medium"},
		{"max_xp_per_match", ""},
		{"maxPrestigeOverride", "Overrides the maximum prestige level, disabled if 0."},
		{"maxVoicePacketsPerSec", ""},
		{"maxVoicePacketsPerSecForServer", ""},
		{"mdsd", "enable match data stat delta logging?"},
		{"melee_debug", "Turn on debug lines for melee traces"},
		{"migration_dvarErrors", "Whether to check for illegal script dvar changes."},
		{"min_wait_for_players", ""},
		{"missileRemoteFOV", "Remote missile-cam, FOV to use."},
		{"missileRemoteSteerPitchRange", "Remote-controlled missile allowed up/down range.  To keep players from steering missiles above the horizon."},
		{"missileRemoteSteerPitchRate", "Remote-controlled missile up/down steering speed."},
		{"missileRemoteSteerYawRate", "Remote-controlled missile left/right steering speed."},
		{"mm_aw_onboarding_rank", "If a player is at or above this rank in AW, she is not considered onboarding"},
		{"mm_blops2_onboarding_skill", "Used to determine onboarding status for Ghosts"},
		{"mm_bucket_option", "if using bucketing, describes what pools can join with each other"},
		{"mm_country_code", "country code"},
		{"mm_ghosts_onboarding_skill", "Used to determine onboarding status for Ghosts"},
		{"mm_past_title_stats_source", "what type of information do we use from the past titles (rank vs kdr, etc)"},
		{"mm_skill_calculation_type", ""},
		{"mm_skill_enforcement", ""},
		{"mm_skill_lower_bucket", "lower mm skill bucket"},
		{"mm_skill_param_delta", "Delta parameter for Johnson SU distribution curve"},
		{"mm_skill_param_gamma", "Gamma parameter for Johnson SU distribution curve"},
		{"mm_skill_param_lambda", "Lambda parameter for Johnson SU distribution curve"},
		{"mm_skill_param_xi", "Xi parameter for Johnson SU distribution curve"},
		{"mm_skill_strict_enforcement", ""},
		{"mm_skill_type", "mm skill type"},
		{"mm_skill_upper_bucket", "upper mm skill bucket"},
		{"mm_sph_1", ""},
		{"mm_sph_10", ""},
		{"mm_sph_11", ""},
		{"mm_sph_12", ""},
		{"mm_sph_13", ""},
		{"mm_sph_14", ""},
		{"mm_sph_15", ""},
		{"mm_sph_16", ""},
		{"mm_sph_17", ""},
		{"mm_sph_18", ""},
		{"mm_sph_2", ""},
		{"mm_sph_3", ""},
		{"mm_sph_4", ""},
		{"mm_sph_5", ""},
		{"mm_sph_6", ""},
		{"mm_sph_7", ""},
		{"mm_sph_8", ""},
		{"mm_sph_9", ""},
		{"mm_split_population", ""},
		{"mm_test_type", "mm test type"},
		{"mm_use_onboarding_skill", "If set, we will for the player's skill to be the lowest available"},
		{"monkeytoy", "Restrict console access"},
		{"motd", ""},
		{"motd_store_link", "Add a link to the in-game store in the MOTD popup"},
		{"motionTrackerBlurDuration", "The motion blur duration for motion tracker dots"},
		{"motionTrackerCenterX", ""},
		{"motionTrackerCenterY", ""},
		{"motionTrackerPingFadeTime", "How long an enemy is visible on the motion tracker after being detected"},
		{"motionTrackerPingPitchAddPerEnemy", "The added percentage of pitch for each additional enemy that is detected (final pitch = base pitch * (1 + enemy count * this))"},
		{"motionTrackerPingPitchBase", "The pitch of the motion tracker sound for a nearby enemy"},
		{"motionTrackerPingPitchNearby", "The pitch of the motion tracker sound for a nearby enemy"},
		{"motionTrackerPingSize", "The width and height of the motion tracker's enemy indicators as a percentage of motion tracker scale"},
		{"msg_field_delta2", "enable the delta2 serialization."},
		{"name", "Player name"},
		{"net_authPort", "UDP port for Steam authentication"},
		{"net_ip", "Network IP Address"},
		{"net_masterServerPort", "UDP port for Steam server browser"},
		{"net_noudp", "Disable UDP"},
		{"net_port", "Network port"},
		{"net_socksEnabled", "Enable network sockets"},
		{"net_socksPassword", "Network socket password"},
		{"net_socksPort", "Network socket port"},
		{"net_socksServer", "Network socket server"},
		{"net_socksUsername", "Network socket username"},
		{"nextmap", "Next map to play"},
		{"nightVisionDisableEffects", ""},
		{"nightVisionFadeInOutTime", "How long the fade to/from black lasts when putting on or removing night vision goggles."},
		{"nightVisionPowerOnTime", "How long the black-to-nightvision fade lasts when turning on the goggles."},
		{"num_available_map_packs", "Number of map packs available for this platform"},
		{"objectiveFontSize", "Onscreen Objective Pointer - Fontsize of the icon's text."},
		{"objectiveTextOffsetY", "Onscreen Objective Pointer - Offset of the icon's text."},
		{"onlinegame", "Current game is an online game with stats, custom classes, unlocks"},
		{"overrideNVGModelWithKnife", "When true, nightvision animations will attach the weapDef's knife model instead of the night vision goggles."},
		{"overtimeTimeLimit", ""},
		{"p2pAuth_allow_steam_p2p", "Determines if Steam based P2P is allowed if direct connectivity is not possible."},
		{"p2pAuth_disable", ""},
		{"paintExplosionRadius", "The radius of the paint grenade explosion"},
		{"painVisionLerpOutRate", "Rate at which pain vision effect lerps out"},
		{"painVisionTriggerHealth", "Health (0 to 1) that will trigger the pain vision effect"},
		{"party_alternateMapVoteStatus", "Alternate map vote progress"},
		{"party_dlc_only_intended_mappacks", "When selecting next map for rotation, should any maps not in the intended search be excluded, even if available?"},
		{"party_firstSubpartyIndex", "Determines sort order and coloring of parties in lobbies.  Randomly set by code.  Dvar provided for debugging."},
		{"party_followPartyHostOutOfGames", "Whether we should follow our party host out of a game in progress."},
		{"party_gamesize", "Current maximum game size"},
		{"party_gametype", "Current gametype"},
		{"party_inactiveHeartbeatPeriod", "How often to send inactive party keep alive packets in milliseconds."},
		{"party_initial_dlc_search_timer", "Time until DLC enabled search should show an error dialog suggesting the user consider going to non dlc search"},
		{"party_IsLocalClientSelected", "True if selected player is a local client.  Only valid when used with party feeders."},
		{"party_kickplayerquestion", "String to store the question about kicking the selected player"},
		{"party_listFocus", "True when an item in the party list has focus."},
		{"party_lobbyPlayerCount", "Number of players currently in the party/lobby"},
		{"party_mapname", "Current map name"},
		{"party_mapvote_entrya_mapname", "Primary map vote entry name"},
		{"party_mapvote_entryb_mapname", "Alternate map vote entry name"},
		{"party_matchedPlayerCount", "Number of matched players before revealing their true names"},
		{"party_maxplayers", "Maximum number of players in a party"},
		{"party_maxPrivatePartyPlayers", "Max number of players allowed in a private party."},
		{"party_maxTeamDiff", "Maximum difference allowed between teams before starting a match"},
		{"party_membersMissingMapPack", "Whether any party member is missing one of the enabled map packs. Only valid after running partyUpdateMissingMapPackDvar"},
		{"party_minLobbyTime", "Minimum time (in seconds) for a lobby to be open before auto starting a match"},
		{"party_minplayers", "Minimum number of players in a party"},
		{"party_nextMapVoteStatus", "Next map vote progress"},
		{"party_partyPlayerCount", "Number of players currently in the party/lobby"},
		{"party_partyPlayerCountNum", "Number of players currently in the party/lobby"},
		{"party_playersCoop", "True if the current playlist places all players on the allies team"},
		{"party_playervisible", "Whether selected player in party is showing true info or not.  Only valid when used with party feeders."},
		{"party_randomMapVoteStatus", "Random map vote progress"},
		{"party_resume_dlc_search_timer", "Time until DLC enabled search should show an error dialog suggesting the user consider going to non dlc search"},
		{"party_search_for_dlc_content", "search for DLC enabled games else standard maps only will be used"},
		{"party_selectedIndex", "Current selected player index in the feeder."},
		{"party_selectedIndexChangedTime", "Time stamp in milliseconds when the selected index last changed."},
		{"party_statusString", "Party Status (localized )"},
		{"party_teambased", "True if the current playlist is team based"},
		{"party_teamsVisible", "teams are visible in UI"},
		{"party_timer", "Time until game begins in seconds, for UI display"},
		{"partyChatDisallowed", "Whether to disallow ps4 Live Party Chat"},
		{"partymigrate_broadcast_interval", "Time between telling people who the new host is when migrating lobby"},
		{"partymigrate_cpuBonusPing", "The ping rewarded to a CPU meeting the bonus threshold when scoring hosts."},
		{"partymigrate_cpuBonusThreshold", "The required excess %CPU speed to get a bonus when scoring hosts."},
		{"partymigrate_logResults", "Instrumentation - Whether to log the best host calculation results. 0 is disabled, 1 for games, 2 for parties, 3 for both."},
		{"partymigrate_makeHostTimeout", "Time before giving up on makeHost requests"},
		{"partymigrate_pingtest_active", "Whether to do a ping test when lobby migrating"},
		{"partymigrate_pingtest_filterThreshold", "Acceptable ping difference from best ping host for host selection (ms)"},
		{"partymigrate_pingtest_minThreshold", "Minimum meaningful ping delta for host selection (ms)"},
		{"partymigrate_pingtest_retry", "Time between ping tests when migrating lobby"},
		{"partymigrate_pingtest_timeout", "Time to give up on ping tests when migrating lobby"},
		{"partymigrate_preferSameHost", "When possible, prefer keeping the same host on migrations"},
		{"partymigrate_selectiontime", "Time before requiring a host selection when migrating lobby"},
		{"partymigrate_timeout", "Time before giving up on lobby migration if we hear nothing"},
		{"partymigrate_timeoutmax", "Time before giving up on lobby migration if we hear nothing"},
		{"partymigrate_uploadtest_minThreshold", "Minimum meaningful upload bandwidth delta for host selection (bps)"},
		{"password", ""},
		{"perk_armorPiercingDamage", ""},
		{"perk_blastShieldScale", ""},
		{"perk_blastShieldScale_HC", ""},
		{"perk_bulletPenetrationMultiplier", "Multiplier for extra bullet penetration"},
		{"perk_extendedMagsMGAmmo", "Number of extra bullets per clip for machine gun weapons with the extended mags perk."},
		{"perk_extendedMagsPistolAmmo", "Number of extra bullets per clip for pistol weapons with the extended mags perk."},
		{"perk_extendedMagsRifleAmmo", "Number of extra bullets per clip for rifle weapons with the extended mags perk."},
		{"perk_extendedMagsSMGAmmo", "Number of extra bullets per clip for sub machine gun weapons with the extended mags perk."},
		{"perk_extendedMagsSpreadAmmo", "Number of extra bullets per clip for spread weapons with the extended mags perk."},
		{"perk_extraBreath", "Number of extra seconds a player can hold his breath"},
		{"perk_fastClimb", "Scales the ladder climb time"},
		{"perk_fastRegenRate", ""},
		{"perk_fastRegenWaitMS", ""},
		{"perk_fastSnipeScale", "Scales the recovery speed of the view kick when using a sniper."},
		{"perk_footstepVolumeAlly", ""},
		{"perk_footstepVolumeEnemy", ""},
		{"perk_footstepVolumePlayer", ""},
		{"perk_footstepVolumeSelectiveHearingMin", ""},
		{"perk_improvedExtraBreath", "Number of extra seconds a player can hold his breath"},
		{"perk_lightWeightViewBobScale", "Scale for first person view movement while lightweight."},
		{"perk_numExtraLethal", "Number of extra lethal grenades"},
		{"perk_numExtraTactical", "Number of extra tactical grenades"},
		{"perk_parabolicAngle", "Eavesdrop perk's effective FOV angle"},
		{"perk_parabolicIcon", "Eavesdrop icon to use when displaying eavesdropped voice chats"},
		{"perk_parabolicRadius", "Eavesdrop perk's effective radius"},
		{"perk_quickDrawSpeedScale", "Scales the 'Hip to ADS' transition speed."},
		{"perk_quickDrawSpeedScaleSniper", "Scales the 'Hip to ADS' transition speed."},
		{"perk_scavengerMode", ""},
		{"perk_sprintMultiplier", "Multiplier for player_sprinttime"},
		{"perk_sprintRecoveryMultiplierActual", ""},
		{"perk_sprintRecoveryMultiplierVisual", ""},
		{"perk_weapRateMultiplier", "Percentage of weapon firing rate to use"},
		{"perk_weapReloadMultiplier", "Percentage of weapon reload time to use"},
		{"perk_weapSpreadMultiplier", "Percentage of weapon spread to use"},
		{"phys_autoDisableLinear", "A body must have linear velocity less than this to be considered idle."},
		{"phys_autoDisableTime", "The amount of time a body must be idle for it to go to sleep."},
		{"phys_bulletSpinScale", "Scale of the effective offset from the center of mass for the bullet impacts."},
		{"phys_bulletUpBias", "Up Bias for the direction of the bullet impact."},
		{"phys_dragAngular", "The amount of angular drag, applied globally"},
		{"phys_dragLinear", "The amount of linear drag, applied globally"},
		{"phys_gravity", "Physics gravity in units/sec^2."},
		{"phys_gravity_ragdoll", "Physics gravity used by ragdolls in units/sec^2."},
		{"phys_gravityChangeWakeupRadius", "The radius around the player within which objects get awakened when gravity changes"},
		{"phys_jitterMaxMass", "Maximum mass to jitter - jitter will fall off up to this mass"},
		{"physVeh_explodeForce", "The force applied to physics vehicles due to explosions"},
		{"physVeh_explodeSpinScale", "The max (random) offset from the center of mass at which splash damage applies its force"},
		{"physVeh_jump", "Set to 1 to make a vehicle jump."},
		{"physVeh_minContactImpulse", "The minimum impulse needed to register a contact notification"},
		{"physVeh_minImpactMomentum", "The minimum collision momentum needed to register an impact"},
		{"physVeh_StepsPerFrame", "The number of physics timesteps that the server frame will be divided into."},
		{"pickupPrints", "Print a message to the game window when picking up ammo, etc."},
		{"player_breath_snd_delay", "The delay before playing the breathe in sound"},
		{"player_breath_snd_lerp", "The interpolation rate for the player hold breath sound"},
		{"player_current_floor", ""},
		{"player_MGUseRadius", "The radius within which a player can mount a machine gun"},
		{"player_stunWhiteFlash", "If enabled, player's screens will flash white when they are stunned."},
		{"player_throwbackInnerRadius", "The radius to a live grenade player must be within initially to do a throwback"},
		{"player_throwbackOuterRadius", "The radius player is allow to throwback a grenade once the player has been in the inner radius"},
		{"player_useRadius", "The radius within which a player can use things"},
		{"playercard_cache_download_max_retry_time", "Max time that the player cache download can retry"},
		{"playercard_cache_download_retry_step", "Step in m/s for the player cache download retry"},
		{"playercard_cache_upload_max_retry_time", "Max time that the player cache upload can retry"},
		{"playercard_cache_upload_retry_step", "Step in m/s for the player cache upload retry"},
		{"playercard_cache_validity_life", "The life of a cached gamercard (it can be re-downloaded after this)"},
		{"playerPositionRecordSampleTime", "How often to sample player positions and save them into match data."},
		{"playlist", "The playlist number"},
		{"playlistAggrFilename", "Aggregated playlist filename"},
		{"playlistFilename", "Playlist filename"},
		{"playListUpdateCheckMinutes", "Minutes to wait between checking for updated playlist."},
		{"prestige_shop_active", "Are we allowed to show the Prestige Shop or not"},
		{"prestige30EasterEggEnabled", "Enables the easter egg for prestige 30 if 1, disabled if 0."},
		{"privateMatch_joinPassword", ""},
		{"privateMatch_serverPassword", ""},
		{"profileMenuOption_blacklevel", ""},
		{"profileMenuOption_offensiveContentMode", "Mode of the offensive content warning at startup - 0, skip and turn on; 1, skip and turn off; 2, ask user"},
		{"profileMenuOption_safeAreaHorz", ""},
		{"profileMenuOption_safeAreaVert", ""},
		{"profileMenuOption_volume", ""},
		{"protocol", "Protocol version"},
		{"pt_AliensReadyUpPrivateInUse", "Do we use the co-op Ready Up feature in public lobbies?"},
		{"pt_AliensReadyUpPublicInUse", "Do we use the co-op Ready Up feature in public lobbies?"},
		{"pt_AliensReadyUpPublicStartTimerLength", "co-op Ready Up start timer length in seconds"},
		{"pt_allMembersDoQoS", "Whether to send search results to all party/lobby members to get QoS data"},
		{"pt_backoutOnClientPresence", "Whether the host should backout the party on client presence. 0=fully disabled, 1=out of game only, 2=in-game also"},
		{"pt_connectAttempts", "Connect timeout when joining another game/party, per attempt"},
		{"pt_connectTimeout", "Connect timeout when joining another game/party, per attempt"},
		{"pt_gameStartTimerLength", "Time in seconds before a game start once enough party members are ready"},
		{"pt_logHostSelectionChance", "Sets the probability that we log our host selection results"},
		{"pt_memberTimeout", "Client timeout time in the general case"},
		{"pt_migrateBeforeAdvertise", "Whether lobbies made by private parties should migrate host before publishing"},
		{"pt_migrationBandwidthBonusPing", "The ping rewarded to the bonus bandwidth threshold when scoring hosts."},
		{"pt_migrationBandwidthBonusThreshold", "The required excess % upload bandwidth to get a bonus when scoring hosts."},
		{"pt_migrationCPUWeight", "How important CPU speed is when selecting a new host"},
		{"pt_migrationNotInstalledWeight", "How important not being done installing is when selecting a new host"},
		{"pt_migrationPingBad", ""},
		{"pt_migrationPingWeight", ""},
		{"pt_migrationQuitsBad", ""},
		{"pt_migrationQuitsWeight", ""},
		{"pt_migrationRAMWeight", "How important it is to have the minimum amount of RAM when selecting a new host"},
		{"pt_migrationThreshold", "Minimum amount which another client must be better than the current host to trigger a migration"},
		{"pt_migrationUploadBad", ""},
		{"pt_migrationUploadWeight", ""},
		{"pt_migrationWifiPenalty", "How important Wifi is when selecting a new host"},
		{"pt_pregameStartTimerLength", "Time in seconds before showing and starting the game start timer"},
		{"pt_rejoin", "Enable defensive rejoin command"},
		{"pt_reservedAnonymousSlotTime", "Time in milliseconds that ANONYMOUS slots will be reserved."},
		{"pt_reservedCommittedSlotTime", "Time in milliseconds that COMMITTED slots will be reserved"},
		{"pt_reservedJoiningSlotTime", "Time in milliseconds that JOINING slots will be reserved"},
		{"pt_searchConnectAttempts", "Connect timeout when joining another game/party, per attempt"},
		{"pt_searchPauseTime", "Minimum amount of time to pause between searches"},
		{"pt_searchRandomDelay", "Time period over which the search timers will get randomly delayed."},
		{"pt_searchResultsLifetime", "Time at which we consider the search results stale"},
		{"pt_searchResultsMin", "Minimum amount of time that has to pass before we'll search again for matches"},
		{"pt_stillConnectingWaitTime", "Amount of time to wait for someone to finish connecting before searching for lobbies to merge with"},
		{"pt_useMigrationWeights", "Killswitch to turn on or off the host selection by weights"},
		{"publisherFileFetchTimeout", "default timeout for publisher files FETCH tasks (in seconds)"},
		{"r_adaptiveSubdiv", "Enables screen space Catmull Clark adaptive tessellation.  If disabled, models tessellate to their designed subdivision level."},
		{"r_adaptiveSubdivBaseFactor", "Screen space Catmull Clark adaptive tessellation factor for the base model.  Smaller values mean more tessellation."},
		{"r_adaptiveSubdivPatchFactor", "Screen space Catmull Clark adaptive tessellation factor for the base model.  Smaller values mean more tessellation."},
		{"r_allCells", "Draw all cells.  Most useful for seeing if portals or cells are hiding things they should not.."},
		{"r_amdGPU", "At least on AMD GPU used for rendering."},
		{"r_aoBlurSharpness", "Controls the tolerance for depth discontinuities during the bilateral blur step.  Larger values reduce the depth tolerance and effectively sharpen more edges."},
		{"r_aoBlurStep", "Step scale applied to sample offsets during the bilateral blur.  A value of 1 results in a normal gaussian blur.  Increasing it to 2 or 3 makes the filter larger but causes fine dithering patterns."},
		{"r_aoDiminish", "Decrease the effect of occlusion on brighter colors"},
		{"r_aoPower", "Power curve applied to AO factor"},
		{"r_aoStrength", "Strength of Ambient Occlusion effect"},
		{"r_aoUseTweaks", "Use r_ao* dvars instead of the current light set values for AO common params"},
		{"r_artUseTweaks", "Tells the game that art tweaks is enabled and script is in control (as opposed to ColorEd)."},
		{"r_aspectRatio", "Screen aspect ratio.  Most widescreen monitors are 16:10 instead of 16:9."},
		{"r_asyncCompute", "Enables scheduling GPU compute shader work prior to the graphics frame, improving overlap."},
		{"r_atlasAnimFPS", "Speed to animate atlased 2d materials"},
		{"r_autopriority", "Automatically set the priority of the windows process when the game is minimized"},
		{"r_balanceLightmapOpaqueLists", "Split lightmap opaque into multiple draw lists."},
		{"r_blacklevel", "Black level (negative brightens output)"},
		{"r_blur", "Dev tweak to blur the screen"},
		{"r_blurdstGaussianBlurLevel", "MIP level to start gaussian blur at"},
		{"r_blurdstGaussianBlurRadius", "Amount to gaussian blur blur distortion render target"},
		{"r_brightness", "Brightness adjustment"},
		{"r_cacheModelLighting", "Speed up model lighting by caching previous results"},
		{"r_cacheSModelLighting", "Speed up static model lighting by caching previous results"},
		{"r_charLightAmbient", ""},
		{"r_clampLodScale", "Clamps the amount that the engine can adjust the LOD distance. 0 the engine can fully adjust. 1 the engine cannot adjust it at all. 0.5 the maximum the engine can adjust the LOD distance is 50% or the default."},
		{"r_clear", "Controls how the color buffer is cleared"},
		{"r_clearColor", "Color to clear the screen to when clearing the frame buffer"},
		{"r_clearColor2", "Color to clear every second frame to (for use during development)"},
		{"r_clutCompositeVisionSet", "Composite clut with vision set."},
		{"r_cmdbuf_worker", "Process command buffer in a separate thread"},
		{"r_colorGradingEnable", "Enable color grading."},
		{"r_colorMap", "Replace all color maps with pure black or pure white"},
		{"r_colorScaleUseTweaks", "Override color scale LightSet settings with tweak dvar values. (MP)"},
		{"r_combinePostOpaqueFx", ""},
		{"r_contrast", "Contrast adjustment"},
		{"r_darkBlur", "Apply blur (decrease of visual acuity) when dark"},
		{"r_darkBlurPower", "Power curve of blurring (decrease of visual acuity) when dark"},
		{"r_darkBlurRadius", "Radius of blurring (decrease of visual acuity) when dark"},
		{"r_darkColor", "Reduce color sensitivity when dark"},
		{"r_darkColorPower", "Power curve of color sensitivity when dark"},
		{"r_debugLineWidth", "Width of server side debug lines"},
		{"r_defaultPatchCount", "Patches per thread group for all other surfaces."},
		{"r_depthPrepass", "Enable depth prepass for various geometries"},
		{"r_depthSortEnable", "Enable sorting of transparent surfaces."},
		{"r_depthSortRange", "Range to consider depth sort,"},
		{"r_desaturation", "Desaturation adjustment"},
		{"r_detailMap", "Replace all detail maps with an image that effectively disables them"},
		{"r_diffuseColorScale", "Globally scale the diffuse color of all point lights"},
		{"r_displacementMap", "Replace all displacement maps with an image that effectively disables them"},
		{"r_displacementPatchCount", "Patches per thread group for displacement surfaces."},
		{"r_distortion", "Enable distortion"},
		{"r_distortion_script_force_off", "Force distortion off in script"},
		{"r_dlightLimit", "Maximum number of dynamic lights drawn simultaneously"},
		{"r_dof_bias", "Depth of field bias as a power function (like gamma); less than 1 is sharper"},
		{"r_dof_enable", "Enable the depth of field effect"},
		{"r_dof_farBlur", ""},
		{"r_dof_farEnd", "Depth of field far end distance, in inches"},
		{"r_dof_farStart", "Depth of field far start distance, in inches"},
		{"r_dof_nearBlur", ""},
		{"r_dof_nearEnd", "Depth of field near end distance, in inches"},
		{"r_dof_nearStart", "Depth of field near start distance, in inches"},
		{"r_dof_physical_adsFocusSpeed", "ADS focus speed (focus dist. far to near, focus dist. near to far, aperture opening, aperture closing)"},
		{"r_dof_physical_adsMaxFstop", "ADS maximum f-stop (optimal aperture and focus distance are automatically calculated for this mode)"},
		{"r_dof_physical_adsMinFstop", "ADS minimum f-stop (optimal aperture and focus distance are automatically calculated for this mode)"},
		{"r_dof_physical_bokehEnable", "Enable the bokeh depth of field effect"},
		{"r_dof_physical_bokehPreset", "Changes dof sampling quality"},
		{"r_dof_physical_bokehRotation", "Bokeh shape rotation in degrees (hexagonal and octogonal only)"},
		{"r_dof_physical_bokehShape", "Changes the bokeh shape"},
		{"r_dof_physical_bokehSharpness", "Bokeh shape sharpness, trades sharpness for stability (circular only)"},
		{"r_dof_physical_enable", "enable physical camera controls (using aperture priority)"},
		{"r_dof_physical_filmDiagonal", "Diagonal size of the film/sensor (mm). The bigger the sensor size, the bigger the circle of confusion (which means stronger blurring at all distances). Defaults to full-frame 35mm"},
		{"r_dof_physical_focusDistance", "Distance to the plane in focus for the scene"},
		{"r_dof_physical_fstop", "Aperture of the camera for the scene. Lower f-stop yields a shallower depth of field. Typical values range from f/1 to f/22. Rare extremes are f/0.75 and f/32"},
		{"r_dof_physical_hipEnable", "Enable hyperfocal mode"},
		{"r_dof_physical_hipFocusSpeed", "Hyperfocal mode focus speed (focus dist. far to near, focus dist. near to far, aperture opening, aperture closing)"},
		{"r_dof_physical_hipFstop", "Aperture of the camera for the scene in the hyperfocal mode"},
		{"r_dof_physical_hipSharpCocDiameter", "Defines what circle of confusion can be considered sharp (mm). Defaults to 0.03mm, generally accepted value for 35mm"},
		{"r_dof_physical_maxCocDiameter", "Maximum circle of confusion diameter (virtual units, might be clamped for bokeh dof)"},
		{"r_dof_physical_minFocusDistance", "Minimum focus distance (inches)"},
		{"r_dof_physical_viewModelFocusDistance", "Distance to the plane in focus for the scene"},
		{"r_dof_physical_viewModelFstop", "Aperture of the camera for the view model. Lower f-stop yields a shallower depth of field. Typical values range from f/1 to f/22. Rare extremes are f/0.75 and f/32"},
		{"r_dof_tweak", "Use dvars to set the depth of field effect; overrides r_dof_enable"},
		{"r_dof_viewModelEnd", "Depth of field viewmodel end distance, in inches"},
		{"r_dof_viewModelStart", "Depth of field viewmodel start distance, in inches"},
		{"r_drawSun", "Enable sun effects"},
		{"r_drawWater", "Enable water animation"},
		{"r_dynamicOPL", "Enable drawing vfx lights as overlapping primary light for saving gpu performance."},
		{"r_dynamicSpotLightShadows", "Enable shadows for dynamic/VFX spot lights, you should set this dvar then spawn the new light."},
		{"r_elevatedPriority", "Utilize priority elevation for process."},
		{"r_emblemBrightnessScale", "Modifier that scales the brightness of the emblem on model materials"},
		{"r_emissiveMap", "Replace all emissive maps with pure black or pure white"},
		{"r_enableNoTessBuckets", "Enables placing triangles that don't need tessellation into additional draw calls using non-tessellated shaders."},
		{"r_envBrdfLutMap", "Replace environment BRDF lookup table with pure black (no secondary specular) or pure white (maximum secondary specular)"},
		{"r_envMapExponent", "Reflection exponent."},
		{"r_envMapMaxIntensity", "Max reflection intensity based on glancing angle."},
		{"r_envMapMinIntensity", ""},
		{"r_envMapOverride", ""},
		{"r_envMapSunIntensity", "Max sun specular intensity intensity with env map materials."},
		{"r_eyePupil", " Change eye's pupil Size."},
		{"r_eyeRedness", " Change eye's redness."},
		{"r_eyeWetness", " Change eye's wetness."},
		{"r_fastModelPrimaryLightCheck", "Reduce R_GetNonSunPrimaryLightForSphere/R_GetNonSunPrimaryLightForBox function calls"},
		{"r_fastModelPrimaryLightLink", "Speed up R_LinkSphereEntityToPrimaryLights and R_LinkBoxEntityToPrimaryLights."},
		{"r_filmAltShader", "Use alternate shader (with middle tint and dark desat) for film color."},
		{"r_filmTweakBrightness", "Tweak dev var; film color brightness"},
		{"r_filmTweakContrast", "Tweak dev var; film color contrast"},
		{"r_filmTweakDarkTint", ""},
		{"r_filmTweakDesaturation", "Tweak dev var; Desaturation applied after all 3D drawing to light areas"},
		{"r_filmTweakDesaturationDark", "Tweak dev var; Additional desaturation applied after all 3D drawing to dark areas"},
		{"r_filmTweakEnable", "Tweak dev var; enable film color effects"},
		{"r_filmTweakInvert", "Tweak dev var; enable inverted video"},
		{"r_filmTweakLightTint", ""},
		{"r_filmTweakMediumTint", ""},
		{"r_filmUseTweaks", "Overide film effects with tweak dvar values."},
		{"r_flushAfterExecute", "Whether to Flush after ExecuteCommandList."},
		{"r_fog", "Set to 0 to disable fog"},
		{"r_fog_depthhack_scale", "Fog scale for depth hack surfaces"},
		{"r_fog_ev_adjust", "Fog color ev adjustment (+2 means fog color is 2 stops brighter)"},
		{"r_font_cache_debug_display", "Display the current fontcache texture on the HUD for debug purposes"},
		{"r_forceLod", "Force all level of detail to this level"},
		{"r_fullbright", "Toggles rendering without lighting"},
		{"r_fxaaSubpixel", "FXAA sub-pixel amount, lower values have more aliasing and less blur"},
		{"r_FXAverageColorFunc", "How to compute FX system average color? 0 = use IWrad equation, 1 = legacy equation, 2 = spherical harmonics 1 coefficient."},
		{"r_globalGenericMaterialScale", "Hack global generic material constants"},
		{"r_glow_allowed", "Allow glow."},
		{"r_glow_allowed_script_forced", "Force 'allow glow' to be treated as true, by script."},
		{"r_gunSightColorEntityScale", "Scale the gun sight color when over an entity."},
		{"r_gunSightColorNoneScale", "Scale the gun sight color when not over an entity."},
		{"r_hbaoBias", "HBAO bias"},
		{"r_hbaoBlurEnable", "HBAO blur enabled"},
		{"r_hbaoBlurSharpness", "HBAO blur sharpness"},
		{"r_hbaoCoarseAO", "HBAO coarse AO"},
		{"r_hbaoDebug", "Debug render HBAO occlusion"},
		{"r_hbaoDetailAO", "HBAO detail AO"},
		{"r_hbaoPowerExponent", "HBAO power exponent"},
		{"r_hbaoRadius", "HBAO radius"},
		{"r_hbaoSceneScale", "HBAO scene scale"},
		{"r_hbaoStrengthBlend", "Blend factor between the artist-tuned proportional strength r_hbaoStrengthScale*artStrength, and the fixed strength r_hbaoStrengthFixed.  A value of 0.0 is fully the proportional value, and a value of 1.0 is fully the fixed value."},
		{"r_hbaoStrengthFixed", "Fixed HBAO strength.  Only used if r_hbaoStrengthBlend > 0.0."},
		{"r_hbaoStrengthScale", "Scale factor to convert SSAO strength to HBAO strength.  Only used if r_hbaoStrengthBlend < 1.0."},
		{"r_hbaoUseScriptScale", "Enable/disable script-controlled strength scale while HBAO is active."},
		{"r_hemiAoBlurTolerance", "Hemi SSAO Blur Tolerance (log10)"},
		{"r_hemiAoCombineResolutionsBeforeBlur", "The higher quality modes blend wide and narrow sampling patterns. The wide pattern is due to deinterleaving and requires blurring. The narrow pattern is not on a deinterleaved buffer, but it only samples every other pixel. The blur on it is optional. If you combine the two before blurring, the narrow will get blurred as well. This creates a softer effect but can remove any visible noise from having 50% sample coverage."},
		{"r_hemiAoCombineResolutionsWithMul", "When combining the wide and narrow patterns, a mul() operation can be used or a min() operation. Multiplication exaggerates the result creating even darker creases. This is an artistic choice. I think it looks less natural, but often art teams prefer more exaggerated contrast. For me, it's more about having the right AO falloff so that it's a smooth gradient rather than falling off precipitously and forming overly dark recesses."},
		{"r_hemiAoDepthSquash", "Hemi SSAO depth squash. Value is rcp."},
		{"r_hemiAoEnable", "Enable Hemi SSAO"},
		{"r_hemiAoHierarchyDepth", "Hemi SSAO recursion depth (filter width)"},
		{"r_hemiAoMaxDepthDownsample", "Use max depth value when downsampling, instead of pseudo-randomly picking a depth sample? Leaving this at the default false may produce more stable results."},
		{"r_hemiAoNoiseFilterTolerance", "This is necessary to filter out pixel shimmer due to bilateral upsampling with too much lost resolution. High frequency detail can sometimes not be reconstructed, and the noise filter fills in the missing pixels with the result of the higher resolution SSAO. Value is log10."},
		{"r_hemiAoPower", "Power curve applied to Hemi SSAO factor, not applied in game yet"},
		{"r_hemiAoQualityLevel", "Hemi SSAO quality setting"},
		{"r_hemiAoRejectionFalloff", "Controls how aggressive to fade off samples that occlude spheres but by so much as to be unreliable. This is what gives objects a dark halo around them when placed in front of a wall. If you want to fade off the halo, boost your rejection falloff. The tradeoff is that it reduces overall AO. Value is rcp."},
		{"r_hemiAoStrength", "Strength of Hemi Screen Space Ambient Occlusion effect"},
		{"r_hemiAoUpsampleTolerance", "Hemi SSAO Upsample Tolerance (log10)"},
		{"r_heroLighting", "Enable hero-only lighting"},
		{"r_highLodDist", "Distance for high level of detail"},
		{"r_hudFx", "Draw HUD Effects"},
		{"r_hudOutlineEnable", "Enables wireframe outlines to be drawn around DObjs (as a post process)."},
		{"r_hudOutlinePostMode", "hud outline apply mode"},
		{"r_hudOutlineWidth", "Set the width of the Hud Outline"},
		{"r_ignore", ""},
		{"r_ignoref", ""},
		{"r_imageQuality", "Image quality"},
		{"r_inGameVideo", "Allow in game cinematics"},
		{"r_lateAllocParamCacheAllowed", "Enable late allocation of parameter cache for VS stage."},
		{"r_lateAllocParamCacheDefault", "Late allocation of parameter cache value for sub-div materials."},
		{"r_lateAllocParamCacheDisplacement", "Late allocation of parameter cache value for sub-div materials."},
		{"r_lateAllocParamCacheSubdiv", "Late allocation of parameter cache value for sub-div materials."},
		{"r_lightCacheLessFrequentMaxDistance", "Adjust the distance fx models (and models tagged as less-frequently-lit by script) move before immediately being relit"},
		{"r_lightCacheLessFrequentPeriod", "Adjust how frequently fx models (and models tagged as less-frequently-lit by script) get relit on average (1 is every frame, 8 is every 8th frame)"},
		{"r_lightGridAvgApplyPrimaryLight", "apply primary light color onto r_showLightGridAvgProbes boxes"},
		{"r_lightGridAvgFollowCamera", "allow the r_showLightGridAvgProbes boxes following current camera position"},
		{"r_lightGridAvgProbeCount", "how many light grid avg color probes will show up)"},
		{"r_lightGridAvgTraceGround", " lock boxes to ground "},
		{"r_lightGridContrast", "Adjust the contrast of light color from the light grid"},
		{"r_lightGridDefaultFXLightingLookup", "Default FX lighting lookup location\n"},
		{"r_lightGridDefaultModelLightingLookup", "Default model lighting lookup location"},
		{"r_lightGridEnableTweaks", "Enable tweaks of the light color from the light grid"},
		{"r_lightGridIntensity", "Adjust the intensity of light color from the light grid"},
		{"r_lightGridSHBands", "Spherical harmonics bands being used for evaluating current-gen light grids colors. 0 = default, 1 = 1 band, 2 = 2 bands, 3 = 3 bands.\n"},
		{"r_lightGridUseTweakedValues", "Use tweaked values instead of default"},
		{"r_lightMap", "Replace all lightmaps with pure black or pure white"},
		{"r_litSurfaceHDRScalar", "Vision set based scalar applied to lit surfaces"},
		{"r_loadForRenderer", "Set to false to disable dx allocations (for dedicated server mode)"},
		{"r_lockPvs", "Lock the viewpoint used for determining what is visible to the current position and direction"},
		{"r_lod4Dist", "Distance for lowest level of detail 4"},
		{"r_lod5Dist", "Distance for lowest level of detail 5"},
		{"r_lodBiasRigid", ""},
		{"r_lodBiasSkinned", ""},
		{"r_lodScaleRigid", ""},
		{"r_lodScaleSkinned", ""},
		{"r_lowestLodDist", "Distance for lowest level of detail"},
		{"r_lowLodDist", "Distance for low level of detail"},
		{"r_mbEnable", "Set of objects which will be enabled for motion blur"},
		{"r_mbFastEnable", "Toggle on/off fast high quality motion blur"},
		{"r_mbFastPreset", "Changes motion blur quality"},
		{"r_mdao", "Enable the medium distance ambient occlusion feature"},
		{"r_mdaoAsyncOccluderGen", "The occluder generation step is performed via async compute"},
		{"r_mdaoBoneInfluenceRadiusScale", "Scale for the bone influence radius for mdao"},
		{"r_mdaoCapsuleStrength", "MDAO strength for capsule occluders"},
		{"r_mdaoMinBoneBoundsToOcclude", "Minimum volume of the bone collider to create occluders for"},
		{"r_mdaoOccluderCullDistance", "Culling distance for mdao occluders"},
		{"r_mdaoOccluderFadeOutStartDistance", "Fade out distance for mdao occluders"},
		{"r_mdaoUseTweaks", "Use r_mdao* dvars instead of the current light set values for MDAO"},
		{"r_mdaoVolumeStrength", "MDAO strength for volume occluders"},
		{"r_mediumLodDist", "Distance for medium level of detail"},
		{"r_mode", "Display mode"},
		{"r_modelLightingMap", "Replace all model lighting maps (light grid) with pure black"},
		{"r_monitor", "Index of the monitor to use in a multi monitor system; 0 picks automatically."},
		{"r_mpRimColor", "Change character's rim color for multiplayer"},
		{"r_mpRimDiffuseTint", "Change character's rim diffuse tint for multiplayer."},
		{"r_mpRimStrength", "Change character's rim color for multiplayer"},
		{"r_multiGPU", "Enable multi GPU compat mode."},
		{"r_normalMap", "Replace all normal maps with a flat normal map"},
		{"r_nvidiaGPU", "Enable NV API."},
		{"r_offchipTessellationAllowed", "Enable off-chip tessellation support."},
		{"r_offchipTessellationTfThreshold", "Tessellation factor threshold for off-chip."},
		{"r_offchipTessellationWaveThreshold", "Domain shader wave threshold for off-chip."},
		{"r_omitUnusedRenderTargets", "Omit unused render targets to save memory.  Changing this requires a vid_restart."},
		{"r_outdoor", "Prevents snow from going indoors"},
		{"r_outdoorFeather", "Outdoor z-feathering value"},
		{"r_particleHdr", "Enable Hdr Particle Features"},
		{"r_patchCountAllowed", "Enable run-time setting of patch count per draw call."},
		{"r_picmip", "Picmip level of color maps.  If r_picmip_manual is 0, this is read-only."},
		{"r_picmip_bump", "Picmip level of normal maps.  If r_picmip_manual is 0, this is read-only."},
		{"r_picmip_spec", "Picmip level of specular maps.  If r_picmip_manual is 0, this is read-only."},
		{"r_picmip_water", "Picmip level of water maps."},
		{"r_polygonOffsetBias", "Offset bias for decal polygons; bigger values z-fight less but poke through walls more"},
		{"r_polygonOffsetClamp", "Offset clamp for decal polygons; bigger values z-fight less but poke through walls more"},
		{"r_polygonOffsetScale", "Offset scale for decal polygons; bigger values z-fight less but poke through walls more"},
		{"r_portalBevels", "Helps cull geometry by angles of portals that are acute when projected onto the screen, value is the cosine of the angle"},
		{"r_portalBevelsOnly", "Use screen-space bounding box of portals rather than the actual shape of the portal projected onto the screen"},
		{"r_portalMinClipArea", "Don't clip child portals by a parent portal smaller than this fraction of the screen area."},
		{"r_portalMinRecurseDepth", "Ignore r_portalMinClipArea for portals with fewer than this many parent portals."},
		{"r_portalWalkLimit", "Stop portal recursion after this many iterations.  Useful for debugging portal errors."},
		{"r_postAA", "Post process antialiasing mode"},
		{"r_postfx_enable", "Enable post-processing effects such as color correction, bloom, depth-of-field, etc."},
		{"r_preloadShaders", "Force D3D to draw dummy geometry with all shaders during level load; may fix long pauses at level start."},
		{"r_primaryLightTweakDiffuseStrength", "Tweak the diffuse intensity for primary lights"},
		{"r_primaryLightTweakSpecularStrength", "Tweak the specular intensity for primary lights"},
		{"r_primaryLightUseTweaks", ""},
		{"r_reactiveMotionActorRadius", "Radial distance from the ai characters that influences reactive motion models (inches)"},
		{"r_reactiveMotionActorVelocityMax", "AI velocity considered the maximum when determining the length of motion tails (inches/sec)"},
		{"r_reactiveMotionActorZOffset", "Distance from the actor origin along Z direction where the actor's reactive motion effector sphere is centered at."},
		{"r_reactiveMotionEffectorStrengthScale", "Additional scale for the effector influence, as a factor of the model part distance from the effector center and model part extents"},
		{"r_reactiveMotionHelicopterLimit", "Maximum number of helicopter entities that actively influence reactive motion.  Can increase CPU cost of the scene."},
		{"r_reactiveMotionHelicopterRadius", "Radial distance from the helicopter that influences reactive motion models (inches)"},
		{"r_reactiveMotionHelicopterStrength", "Scales the influence of helicopter wind tunnel motion"},
		{"r_reactiveMotionPlayerHeightAdjust", "Amount to adjust the vertical distance of the effector from the player position (inches)"},
		{"r_reactiveMotionPlayerRadius", "Radial distance from the player that influences reactive motion models (inches)"},
		{"r_reactiveMotionPlayerZOffset", "Distance from the player origin along Z direction where the player's reactive motion effector sphere is centered at."},
		{"r_reactiveMotionVelocityTailScale", "Additional scale for the velocity-based motion tails, as a factor of the effector radius"},
		{"r_reactiveMotionWindAmplitudeScale", "Scales amplitude of wind wave motion"},
		{"r_reactiveMotionWindAreaScale", "Scales distribution of wind motion"},
		{"r_reactiveMotionWindDir", "Controls the global wind direction"},
		{"r_reactiveMotionWindFrequencyScale", "Scales frequency of wind wave motion"},
		{"r_reactiveMotionWindStrength", "Scale of the global wind direction (inches/sec)"},
		{"r_reflectionProbeMap", "Replace all reflection probes with pure black"},
		{"r_reflectionProbeNmlLuminance", "Enable/disable shader code for computing luminance during reflection probe denormalization. This is just an experiment.\n"},
		{"r_rimLight0Color", ""},
		{"r_rimLight0Heading", "Rim Light 0 heading in degrees"},
		{"r_rimLight0Pitch", "Rim Light 0 pitch in degrees -90 is noon."},
		{"r_rimLightBias", "How much to bias the n.l calculation"},
		{"r_rimLightDiffuseIntensity", "Strength of the diffuse component of the rim light."},
		{"r_rimLightFalloffMaxDistance", "Distance at which the rim light hits intensity of 100%."},
		{"r_rimLightFalloffMinDistance", "Distance at which the rim light hits intensity of 100%."},
		{"r_rimLightFalloffMinIntensity", "Intensity of the effect at and before minDistance."},
		{"r_rimLightPower", "Power to raise the n.l calculation"},
		{"r_rimLightSpecIntensity", "Strength of the spec ( additive) component of the rim light"},
		{"r_rimLightUseTweaks", "Turn on rim lighting tweaks"},
		{"r_scaleViewport", "Scale 3D viewports by this fraction.  Use this to see if framerate is pixel shader bound."},
		{"r_sceneMipShowOverlay", "Toggles scene mip rendertarget overlay"},
		{"r_showLightGrid", "Show light grid debugging information (2: detailed, 3: detailed for this box only)"},
		{"r_showLightGridAvgProbes", "show an array of boxes which are using the light grid average color at its location"},
		{"r_showLightGridDetailInfo", "Show more details for light grid debugging."},
		{"r_showLightProbes", "Show the light probes at the light grid sample locations in world space centered around the camera."},
		{"r_showMissingLightGrid", "Use rainbow colors for entities that are outside the light grid"},
		{"r_showModelLightingLowWaterMark", ""},
		{"r_showPortals", "Show portals for debugging"},
		{"r_showPortalsOverview", "Render 2d XY portal overlay scaled to fit to this distance.  Useful for debugging portal errors."},
		{"r_showReflectionProbeSelection", "Show reflection probe selection"},
		{"r_singleCell", "Only draw things in the same cell as the camera.  Most useful for seeing how big the current cell is."},
		{"r_skipPvs", "Skipt the determination of what is in the potentially visible set (disables most drawing)"},
		{"r_sky_fog_intensity", "Amount of sky fog fading"},
		{"r_sky_fog_max_angle", "End of angular sky fog fading"},
		{"r_sky_fog_min_angle", "Start of angular sky fog fading"},
		{"r_skyFogUseTweaks", "Enable dvar control of sky fog"},
		{"r_smaaThreshold", "SMAA edge detection threshold"},
		{"r_smodelInstancedRenderer", "Render static models with instanced renderer"},
		{"r_smodelInstancedThreshold", "Minimum number of static model instances before instanced rendering is used"},
		{"r_smp_backend", "Process renderer back end in a separate thread"},
		{"r_smp_worker", "Process renderer front end in a separate thread"},
		{"r_smp_worker_thread0", ""},
		{"r_smp_worker_thread1", ""},
		{"r_smp_worker_thread2", ""},
		{"r_smp_worker_thread3", "undefined"},
		{"r_smp_worker_thread4", "undefined"},
		{"r_smp_worker_thread5", "undefined"},
		{"r_smp_worker_thread6", "undefined"},
		{"r_smp_worker_thread7", "undefined"},
		{"r_specOccMap", "Replace all specular occlusion maps with pure black (fully occluded) or pure white (not occluded)"},
		{"r_specularColorScale", "Set greater than 1 to brighten specular highlights"},
		{"r_specularMap", "Replace all specular maps with pure black (off) or pure white (super shiny)"},
		{"r_spotLightEntityShadows", "Enable entity shadows for spot lights."},
		{"r_spotLightShadows", "Enable shadows for spot lights."},
		{"r_ssao", "Screen Space Ambient Occlusion mode"},
		{"r_ssaoDebug", "Render calculated or blurred Screen Space Ambient Occlusion values"},
		{"r_ssaoDebugMip", "Selects which mip level to render when r_ssaoDebug is enabled. If 0 and r_ssaoDownsample is enabled, will render mip 1."},
		{"r_ssaoDepthScale", "Scale applied to depth values used for occlusion tests."},
		{"r_ssaoDepthScaleViewModel", "Scale applied to depth values used for occlusion tests."},
		{"r_ssaoDownsample", "Screen Space Ambient Occlusion calculation occurs at half linear resolution"},
		{"r_ssaoFadeDepth", "Depth at which the SSAO begins to fade out.  It fades at even increments of this distance (e.g. it's at 1 for depth r_ssaoFadeDepth, 1/2 for depth 2*r_ssaoFadeDepth, etc.)"},
		{"r_ssaoGapFalloff", "Falloff used to blend between creases (that should darken) and silhouettes (that should not darken).  Lower values falloff more quickly."},
		{"r_ssaoGradientFalloff", "Falloff used to fade out the effect for steep depth gradients (i.e. surfaces nearly parallel to the camera direction).  This fixes sampling artifacts that appear for surfaces nearly parallel to the camera direction (commonly occuring for flat ground planes)."},
		{"r_ssaoMaxStrengthDepth", "Depth at which SSAO strength is at its maximum"},
		{"r_ssaoMethod", "Screen Space Ambient Occlusion method (original or IW6, both are volumetric obscurance)"},
		{"r_ssaoMinPixelWidth", "Minimum pixel width of the effect.  When the effect is smaller than this, it is culled entirely."},
		{"r_ssaoMinStrengthDepth", "Depth at which SSAO strength is zero, effectively disabled"},
		{"r_ssaoMultiRes", "Screen Space Ambient Occlusion calculation occurs at half linear resolution"},
		{"r_ssaoPower", "Power curve applied to SSAO factor"},
		{"r_ssaoRejectDepth", "Depth at which the SSAO is disabled.  Smaller values result in more rejected pixels which is faster, but limits the distance at which the effect is visible."},
		{"r_ssaoSampleCount", "Selects the number of samples used for SSAO"},
		{"r_ssaoScriptScale", "Allows script to lerp to disable or enable the SSAO.  This applies a scalar value to the SSAO strength.  When set to 0, this effectively disables SSAO."},
		{"r_ssaoStrength", "Strength of Screen Space Ambient Occlusion effect"},
		{"r_ssaoUseTweaks", "Use r_ssao* dvars instead of the current light set values for SSAO"},
		{"r_ssaoWidth", "The width of the SSAO effect, in pixels at 720p.  Larger values increase area but lower effective quality."},
		{"r_sse_skinning", "Use Streaming SIMD Extensions for skinning"},
		{"r_ssrBlendScale", "Add extra scale to ssr weight versus reflection probe weight, >1 value will make ssr more obvious."},
		{"r_ssrFadeInDuration", "Duration of the screen-space reflection fade-in, which occurs whenever the reflection source buffer is invalidated due to view changes (in particular, dual-view scope transitions)."},
		{"r_ssrPositionCorrection", "Screen space reflection position correction blend factor"},
		{"r_ssrRoughnessMipParameters", "X: mirror mip; Y: roughest mip; Z: roughness middle point, may need different value for different screen resolution on PC."},
		{"r_sssBlendWeight", "Controls the blend between the wide (zero) and narrow (one) gaussians"},
		{"r_sssDebugMaterial", "Debug Feature: toggle materials with SSS"},
		{"r_sssEnable", "Enables the subsurface scattering effect (note that disabling SSS will not prevent the filter from running)"},
		{"r_sssGlobalRadius", "Controls the global radius (in inches)"},
		{"r_sssJitterRadius", "Percentage of the kernel to be jittered"},
		{"r_sssNarrowRadius", "Controls the narrow Gaussian radius"},
		{"r_sssPreset", "Changes subsurface scattering quality"},
		{"r_sssWideRadius", "Controls the wide Gaussian radius"},
		{"r_subdiv", "Enables Catmull Clark surface subdivision."},
		{"r_subdivLimit", "Set the maximum Catmull Clark subdivision level."},
		{"r_subdivPatchCount", "Patches per thread group for sub-division surfaces."},
		{"r_subdomainLimit", "Maximum number of extra tessellation subdivisions using instancing (max tess amts are 0:64, 1:128, 2:192, 3:256, max instances used are 0:1, 1:4, 2:9, 3:12)"},
		{"r_subdomainScale", "Debug only: Scales the extra subdivision amount (for values < 1, not all instanced sub triangles will draw)."},
		{"r_subwindow", "subwindow to draw: left, right, top, bottom"},
		{"r_sun_from_dvars", "Set sun flare values from dvars rather than the level"},
		{"r_sun_fx_position", "Position in degrees of the sun effect"},
		{"r_sunblind_fadein", "time in seconds to fade blind from 0% to 100%"},
		{"r_sunblind_fadeout", "time in seconds to fade blind from 100% to 0%"},
		{"r_sunblind_max_angle", "angle from sun in degrees inside which effect is max"},
		{"r_sunblind_max_darken", "0-1 fraction for how black the world is at max blind"},
		{"r_sunblind_min_angle", "angle from sun in degrees outside which effect is 0"},
		{"r_sunflare_fadein", "time in seconds to fade alpha from 0% to 100%"},
		{"r_sunflare_fadeout", "time in seconds to fade alpha from 100% to 0%"},
		{"r_sunflare_max_alpha", "0-1 vertex color and alpha of sun at max effect"},
		{"r_sunflare_max_angle", "angle from sun in degrees inside which effect is max"},
		{"r_sunflare_max_size", "largest size of flare effect in pixels at 640x480"},
		{"r_sunflare_min_angle", "angle from sun in degrees outside which effect is 0"},
		{"r_sunflare_min_size", "smallest size of flare effect in pixels at 640x480"},
		{"r_sunflare_shader", "name for flare effect; can be any material"},
		{"r_sunglare_fadein", "time in seconds to fade glare from 0% to 100%"},
		{"r_sunglare_fadeout", "time in seconds to fade glare from 100% to 0%"},
		{"r_sunglare_max_angle", "angle from sun in degrees inside which effect is max"},
		{"r_sunglare_max_lighten", "0-1 fraction for how white the world is at max glare"},
		{"r_sunglare_min_angle", "angle from sun in degrees inside which effect is max"},
		{"r_sunInfDist", "Sun infinite distance used to place sun fx"},
		{"r_sunshadowmap_cmdbuf_worker", "Process shadowmap command buffer in a separate thread"},
		{"r_sunsprite_shader", "name for static sprite; can be any material"},
		{"r_sunsprite_size", "diameter in pixels at 640x480 and 80 fov"},
		{"r_surfaceHDRScalarUseTweaks", "Enables lit and unlit surface scalar tweaks"},
		{"r_tessellation", "Enables tessellation of world geometry, with an optional cutoff distance."},
		{"r_tessellationCutoffDistance", "Distance at which world geometry ceases to tessellate."},
		{"r_tessellationCutoffFalloff", "Range over which tessellation is faded out, up to the cutoff."},
		{"r_tessellationEyeScale", "Scale applied due to eye * object normal for less tessellation on facing polygons."},
		{"r_tessellationFactor", "Target edge length, based on dividing full window height by this factor, for dynamic tessellation.  Use zero to disable tessellation."},
		{"r_tessellationHeightAuto", "Correctly auto scale displacement heights for layers to grow as texture is stretched over larger surface areas to preserve feature proportions."},
		{"r_tessellationHeightScale", "Displacement height scale factor."},
		{"r_tessellationHybrid", "Hybrid per pixel displacement scale."},
		{"r_tessellationLodBias", "Displacement map lod bias."},
		{"r_texFilterAnisoMax", "Maximum anisotropy to use for texture filtering"},
		{"r_texFilterAnisoMin", "Minimum anisotropy to use for texture filtering (overridden by max)"},
		{"r_texFilterDisable", "Disables all texture filtering (uses nearest only.)"},
		{"r_texFilterMipBias", "Change the mipmap bias"},
		{"r_texFilterMipMode", "Forces all mipmaps to use a particular blend between levels (or disables mipping.)"},
		{"r_texFilterProbeBilinear", "Force reflection probe to use bilinear filter"},
		{"r_texShowMipMode", "Forces textures with the specified mip filtering to draw black."},
		{"r_thermalColorOffset", "Offset of the thermal colors (offset + scale*color)"},
		{"r_thermalColorScale", "Scale of the thermal colors (offset + scale*color)"},
		{"r_thermalDetailScale", "Scale of the detail that is added to the thermal map from the normal map (multiplies the detail amount from AssetManager)"},
		{"r_thermalFadeColor", "Color the thermal fades to at distance."},
		{"r_thermalFadeControl", "Select thermal fade mode"},
		{"r_thermalFadeMax", "Distance at which thermal stops fading"},
		{"r_thermalFadeMin", "Distance at which thermal starts fading"},
		{"r_tonemap", "HDR Tonemapping mode"},
		{"r_tonemapAdaptSpeed", "HDR Tonemap exposure adaptation speed"},
		{"r_tonemapAuto", "HDR Tonemapping performs auto-exposure"},
		{"r_tonemapAutoExposureAdjust", "HDR Tonemap Auto Exposure Adjust value (set to 0.0 for automatic adjustment)"},
		{"r_tonemapBlack", "HDR Filmic Tonemap black point"},
		{"r_tonemapBlend", "HDR Tonemapping blends between exposures"},
		{"r_tonemapCrossover", "HDR Filmic Tonemap crossover point"},
		{"r_tonemapDarkEv", "HDR Tonemap Dark EV"},
		{"r_tonemapDarkExposureAdjust", "HDR Tonemap Dark Exposure Adjust"},
		{"r_tonemapExposure", "HDR Tonemap exposure (in EV) override (only works in non-auto mode)"},
		{"r_tonemapExposureAdjust", "HDR Tonemap exposure adjustment (in EV, 0 is no adjustment, works like a camera where +1 reduces EV by 1)"},
		{"r_tonemapGamma", "HDR Tonemap gamma curve power"},
		{"r_tonemapHighlightRange", "HDR Tonemap dynamic range, which determines white point luminance"},
		{"r_tonemapLightEv", "HDR Tonemap Light EV"},
		{"r_tonemapLightExposureAdjust", "HDR Tonemap Light Exposure Adjust"},
		{"r_tonemapLockAutoExposureAdjust", "HDR Tonemapping lock auto exposure adjust"},
		{"r_tonemapMaxExposure", "HDR Tonemap maximum exposure (in EV)"},
		{"r_tonemapMaxExposureAdjust", "HDR Tonemap Max Exposure Adjust"},
		{"r_tonemapMidEv", "HDR Tonemap Mid EV"},
		{"r_tonemapMidExposureAdjust", "HDR Tonemap Mid Exposure Adjust"},
		{"r_tonemapMinExposureAdjust", "HDR Tonemap Min Exposure Adjust"},
		{"r_tonemapShoulder", "HDR Filmic Tonemap shoulder control (0 is linear)"},
		{"r_tonemapToe", "HDR Filmic Tonemap toe control  (0 is linear)"},
		{"r_tonemapUseCS", "HDR Tonemapping uses compute shader."},
		{"r_tonemapUseTweaks", "Override tone map LightSet settings with tweak dvar values."},
		{"r_tonemapWhite", "HDR Filmic Tonemap white point"},
		{"r_ui3d_debug_display", "Show UI3D debug overlay"},
		{"r_ui3d_h", "ui3d texture window height"},
		{"r_ui3d_use_debug_values", "Use UI debug values"},
		{"r_ui3d_w", "ui3d texture window width"},
		{"r_ui3d_x", "ui3d texture window x"},
		{"r_ui3d_y", "ui3d texture window y"},
		{"r_uiBlurDstMode", "UI blur distortion mode. Fast uses the scene mip map render target, PostSun uses a downsampled post sun resolve buffer, PostSun HQ uses a gaussian blurred post sun resolve buffer."},
		{"r_umbra", "Enables Umbra-based portal culling."},
		{"r_umbraAccurateOcclusionThreshold", "The distance (in inches) to which accurate occlusion information is gathered. -1.0 = deduced automatically."},
		{"r_umbraExclusive", "Toggle Umbra for exclusive static culling (disables static portal dpvs)"},
		{"r_umbraQueryParts", "The number of parts the Umbra query frustum is broken into for async query processing as an M x N grid (0, 0 = all queries are synchronous)."},
		{"r_umbraUseBadPlaces", "Enable/disable ability to disable umbra when inside special volumes defined in mp/umbraBadPlaces.csv."},
		{"r_umbraUseDpvsCullDist", "Use cull distance from the DPVS instead of the far plane distance."},
		{"r_unlitSurfaceHDRScalar", "Vision set based scalar applied to unlit surfaces to balance those surfaces with the luminance of the scene"},
		{"r_useComputeSkinning", "Enables compute shader (GPU) skinning."},
		{"r_useLayeredMaterials", "Set to true to use layered materials on shader model 3 hardware"},
		{"r_useLightGridDefaultFXLightingLookup", "Enable/disable default fx lighting lookup\n"},
		{"r_useLightGridDefaultModelLightingLookup", "Enable/disable default model lighting lookup\n"},
		{"r_useShadowGeomOpt", "Enable iwRad shadow geometry optimization. It only works when we have the data generated in iwRad."},
		{"r_useSunShadowPortals", "Enable sun shadow portals when dir light change and not using cached shadow."},
		{"r_useXAnimIK", "Enables IK animation."},
		{"r_vc_makelog", "Enable logging of light grid points for the vis cache.  1 starts from scratch, 2 appends."},
		{"r_vc_showlog", "Show this many rows of light grid points for the vis cache"},
		{"r_veil", "Apply veiling luminance (HDR glow)"},
		{"r_veilAntialiasing", "Veil antialiasing mode (downsample technique used for first mip)."},
		{"r_veilBackgroundStrength", "Strength of background when applying veiling luminance (HDR glow)"},
		{"r_veilFalloffScale1", "Controls the size of individual Gaussians (Gaussians 4-6 in XYZ, where Gaussian 6 is the wider one)"},
		{"r_veilFalloffScale2", "Controls the size of individual Gaussians (Gaussians 4-6 in XYZ, where Gaussian 6 is the wider one)"},
		{"r_veilFalloffWeight1", "Controls the weight of individual Gaussians (Gaussians 4-6 in XYZ, where Gaussian 6 is the wider one)"},
		{"r_veilFalloffWeight2", "Controls the weight of individual Gaussians (Gaussians 4-6 in XYZ, where Gaussian 6 is the wider one)"},
		{"r_veilFilter", "Changes the veil filtering mode"},
		{"r_veilPreset", "Changes veil sampling quality"},
		{"r_veilRadius", "Controls the radius of the first Gaussian in virtual pixels (remaining Gaussians follow proportionally)."},
		{"r_veilStrength", "Strength of veiling luminance (HDR glow)"},
		{"r_veilUseTweaks", "Override veil LightSet settings with tweak dvar values."},
		{"r_velocityPrepass", "Perform velocity rendering during the depth prepass"},
		{"r_viewModelLightAmbient", ""},
		{"r_viewModelPrimaryLightTweakDiffuseStrength", "Tweak the diffuse intensity for view model primary lights"},
		{"r_viewModelPrimaryLightTweakSpecularStrength", "Tweak the specular intensity for view model primary lights"},
		{"r_viewModelPrimaryLightUseTweaks", ""},
		{"r_volumeLightScatter", "Enables volumetric light scattering"},
		{"r_volumeLightScatterAngularAtten", "Distance of sun from center of screen before angular attenuation starts for god rays"},
		{"r_volumeLightScatterBackgroundDistance", "Distance at which pixels are considered background for volume light scatter effect"},
		{"r_volumeLightScatterColor", ""},
		{"r_volumeLightScatterDepthAttenFar", "Pixels >= than this depth recieve full volume light scatter."},
		{"r_volumeLightScatterDepthAttenNear", "Pixels <= than this depth recieve no volume light scatter."},
		{"r_volumeLightScatterEv", "Light intensity (in EV) for volumetric light scattering"},
		{"r_volumeLightScatterLinearAtten", "Coefficient of linear attenuation of god rays"},
		{"r_volumeLightScatterQuadraticAtten", "Coefficient of quadratic attenuation of god rays)"},
		{"r_volumeLightScatterUseTweaks", "Enables volumetric light scattering tweaks"},
		{"r_vsync", "Enable v-sync before drawing the next frame to avoid 'tearing' artifacts."},
		{"r_warningRepeatDelay", "Number of seconds after displaying a \"per-frame\" warning before it will display again"},
		{"r_wideTessFactorsThreshold", "If a surface has more than this many triangles, process triangles in parallel instead of surfaces."},
		{"r_zfar", "Change the distance at which culling fog reaches 100% opacity; 0 is off"},
		{"r_znear", "Things closer than this aren't drawn.  Reducing this increases z-fighting in the distance."},
		{"radarjamDistMax", ""},
		{"radarjamDistMin", ""},
		{"radarjamSinCurve", ""},
		{"radius_damage_debug", "Turn on debug lines for radius damage traces"},
		{"ragdoll_baselerp_time", "Default time ragdoll baselerp bones take to reach the base pose"},
		{"ragdoll_bullet_force", "Bullet force applied to ragdolls"},
		{"ragdoll_bullet_upbias", "Upward bias applied to ragdoll bullet effects"},
		{"ragdoll_dump_anims", "Dump animation data when ragdoll fails"},
		{"ragdoll_enable", "Turn on ragdoll death animations"},
		{"ragdoll_explode_force", "Explosive force applied to ragdolls"},
		{"ragdoll_explode_upbias", "Upwards bias applied to ragdoll explosion effects"},
		{"ragdoll_exploding_bullet_force", "Force applied to ragdolls from explosive bullets"},
		{"ragdoll_exploding_bullet_upbias", "Upwards bias applied to ragdoll from explosive bullets"},
		{"ragdoll_idle_min_velsq", "Minimum squared speed a ragdoll body needs to be moving before it will shut down due to time"},
		{"ragdoll_jitter_scale", "Scale up or down the effect of physics jitter on ragdolls"},
		{"ragdoll_jointlerp_time", "Default time taken to lerp down ragdoll joint friction"},
		{"ragdoll_link_to_moving_platform", "Enable client-side linking of ragdolls to script brush models when they go idle."},
		{"ragdoll_max_life", "Max lifetime of a ragdoll system in msec"},
		{"ragdoll_max_simulating", "Max number of simultaneous active ragdolls - archived"},
		{"ragdoll_max_stretch_pct", "Force ragdoll limbs to not stretch more than this percentage in one frame"},
		{"ragdoll_mp_limit", "Max number of simultaneous active ragdolls - archived"},
		{"ragdoll_mp_resume_share_after_killcam", "Msec after returning from killcam that splitscreen players will share ragdolls again."},
		{"ragdoll_resolve_penetration_bias", "Bias value on force to push ragdolls out of environment."},
		{"ragdoll_rotvel_scale", "Ragdoll rotational velocity estimate scale"},
		{"ragdoll_self_collision_scale", "Scale the size of the collision capsules used to prevent ragdoll limbs from interpenetrating"},
		{"ragdoll_stretch_iters", "Iterations to run the alternate limb solver"},
		{"rankedPlayEndMatchKeepLobby", "keep the lobby if the lobby host is in our private party."},
		{"rankedPlaylistLockoutDuration", "Time in seconds to lock the ranked play playlist if a player quit the match early."},
		{"rate", "Player's preferred network rate"},
		{"RemoteCameraSounds_DryLevel", ""},
		{"RemoteCameraSounds_RoomType", ""},
		{"RemoteCameraSounds_WetLevel", ""},
		{"requireOpenNat", ""},
		{"restrictMapPacksToGroups", "Restrict map pack usage to needing all maps in an ala carte package in order to use as search criteria"},
		{"riotshield_bullet_damage_scale", "Value to scale bullet damage to deployed riotshield."},
		{"riotshield_deploy_limit_radius", "Min distance deployed riotshields must be from each other."},
		{"riotshield_deploy_trace_parallel", "Report collisions when riotshield traces are parallel to plane of triangle.  If disabled traces parallel to triangle planes do not report collisions at all."},
		{"riotshield_deployed_health", "Deployed riotshield health."},
		{"riotshield_destroyed_cleanup_time", "Time (in seconds) destroyed riotshield model persists before disappearing"},
		{"riotshield_explosive_damage_scale", "Value to scale explosive damage to deployed riotshield.."},
		{"riotshield_melee_damage_scale", "Value to scale melee damage to deployed riotshield."},
		{"riotshield_projectile_damage_scale", "Value to scale projectile damage to deployed riotshield."},
		{"s_aggregate_ping_offset", "offset to apply to aggregate ping values"},
		{"s_aggregate_ping_scale", "8-bit fixed-point aggregate ping scaler value"},
		{"s_avg_max_weighting", "weighting from 0-256 of party average ping vs. worst ping"},
		{"s_ds_pingclient_reping_wait_db", "wait this# of frames for the db thread to settle down before repinging"},
		{"s_use_aggregate_datacenter_pings", "use newer system for aggregating party pings"},
		{"safeArea_adjusted_horizontal", "User-adjustable horizontal safe area as a fraction of the screen width"},
		{"safeArea_adjusted_vertical", "User-adjustable vertical safe area as a fraction of the screen height"},
		{"safeArea_horizontal", "Horizontal safe area as a fraction of the screen width"},
		{"safeArea_vertical", "Vertical safe area as a fraction of the screen height"},
		{"scr_conf_numlives", ""},
		{"scr_conf_playerrespawndelay", ""},
		{"scr_conf_roundlimit", ""},
		{"scr_conf_scorelimit", ""},
		{"scr_conf_timelimit", ""},
		{"scr_conf_waverespawndelay", ""},
		{"scr_conf_winlimit", ""},
		{"scr_default_maxagents", ""},
		{"scr_diehard", ""},
		{"scr_disableClientSpawnTraces", ""},
		{"scr_dm_numlives", ""},
		{"scr_dm_playerrespawndelay", ""},
		{"scr_dm_roundlimit", ""},
		{"scr_dm_scorelimit", ""},
		{"scr_dm_timelimit", ""},
		{"scr_dm_waverespawndelay", ""},
		{"scr_dm_winlimit", ""},
		{"scr_dom_numlives", ""},
		{"scr_dom_playerrespawndelay", ""},
		{"scr_dom_roundlimit", ""},
		{"scr_dom_scorelimit", ""},
		{"scr_dom_timelimit", ""},
		{"scr_dom_waverespawndelay", ""},
		{"scr_dom_winlimit", ""},
		{"scr_explBulletMod", ""},
		{"scr_game_allowkillcam", "script allow killcam"},
		{"scr_game_deathpointloss", ""},
		{"scr_game_forceuav", ""},
		{"scr_game_graceperiod", ""},
		{"scr_game_hardpoints", ""},
		{"scr_game_killstreakdelay", ""},
		{"scr_game_lockspectatorpov", "Lock spectator mode globally, 0=freelook/unlocked, 1=first_person, 2=third_person"},
		{"scr_game_onlyheadshots", ""},
		{"scr_game_perks", ""},
		{"scr_game_spectatetype", ""},
		{"scr_game_suicidepointloss", ""},
		{"scr_gameended", ""},
		{"scr_hardcore", ""},
		{"scr_horde_difficulty", ""},
		{"scr_horde_maxagents", ""},
		{"scr_horde_numlives", ""},
		{"scr_horde_playerrespawndelay", ""},
		{"scr_horde_roundlimit", ""},
		{"scr_horde_scorelimit", ""},
		{"scr_horde_timelimit", ""},
		{"scr_horde_waverespawndelay", ""},
		{"scr_horde_winlimit", ""},
		{"scr_infect_numlives", ""},
		{"scr_infect_playerrespawndelay", ""},
		{"scr_infect_roundlimit", ""},
		{"scr_infect_timelimit", ""},
		{"scr_infect_waverespawndelay", ""},
		{"scr_infect_winlimit", ""},
		{"scr_isgamescom", "script use gamescom demo flow"},
		{"scr_maxPerPlayerExplosives", ""},
		{"scr_nukeCancelMode", ""},
		{"scr_nukeTimer", ""},
		{"scr_patientZero", ""},
		{"scr_player_forcerespawn", ""},
		{"scr_player_healthregentime", ""},
		{"scr_player_maxhealth", ""},
		{"scr_player_numlives", ""},
		{"scr_player_respawndelay", ""},
		{"scr_player_sprinttime", ""},
		{"scr_player_suicidespawndelay", ""},
		{"scr_RequiredMapAspectratio", ""},
		{"scr_riotShieldXPBullets", ""},
		{"scr_sd_bombtimer", ""},
		{"scr_sd_defusetime", ""},
		{"scr_sd_multibomb", ""},
		{"scr_sd_numlives", ""},
		{"scr_sd_planttime", ""},
		{"scr_sd_playerrespawndelay", ""},
		{"scr_sd_roundlimit", ""},
		{"scr_sd_roundswitch", ""},
		{"scr_sd_scorelimit", ""},
		{"scr_sd_timelimit", ""},
		{"scr_sd_waverespawndelay", ""},
		{"scr_sd_winlimit", ""},
		{"scr_sr_bombtimer", ""},
		{"scr_sr_defusetime", ""},
		{"scr_sr_multibomb", ""},
		{"scr_sr_numlives", ""},
		{"scr_sr_planttime", ""},
		{"scr_sr_playerrespawndelay", ""},
		{"scr_sr_roundlimit", ""},
		{"scr_sr_roundswitch", ""},
		{"scr_sr_scorelimit", ""},
		{"scr_sr_timelimit", ""},
		{"scr_sr_waverespawndelay", ""},
		{"scr_sr_winlimit", ""},
		{"scr_team_fftype", "script team friendly fire type"},
		{"scr_team_respawntime", ""},
		{"scr_team_teamkillpointloss", ""},
		{"scr_team_teamkillspawndelay", ""},
		{"scr_thirdPerson", ""},
		{"scr_tispawndelay", ""},
		{"scr_war_halftime", ""},
		{"scr_war_numlives", ""},
		{"scr_war_playerrespawndelay", ""},
		{"scr_war_roundlimit", ""},
		{"scr_war_roundswitch", ""},
		{"scr_war_scorelimit", ""},
		{"scr_war_timelimit", ""},
		{"scr_war_waverespawndelay", ""},
		{"scr_war_winlimit", ""},
		{"scr_xpscale", ""},
		{"screenshots_active", "Are we allowed to enable Screenshots or not"},
		{"search_weight_asn", "The weight used for the asn in weighted matchmaking."},
		{"search_weight_country_code", "The weight used for the country code in weighted matchmaking."},
		{"search_weight_lat_long", "The weight used for the lat long in weighted matchmaking."},
		{"sensitivity", "Mouse sensitivity"},
		{"sentry_placement_feet_offset", "Position of the feet from the center axis."},
		{"sentry_placement_feet_trace_dist_z", "Max distance for a foot to be considered touching the ground"},
		{"sentry_placement_trace_dist", "Distance along the trace axis where the sentry will attempt to position itself"},
		{"sentry_placement_trace_min_normal", "Minimum normal to accept a sentry position"},
		{"sentry_placement_trace_parallel", "Enable turret traces that are parallel to plane of triangle.  If 0, traces parallel to triangle planes do not report collisions at all.  If 2 (debug-only), then trace code ping pongs between new and old."},
		{"sentry_placement_trace_pitch", "Pitch used for the trace axis"},
		{"sentry_placement_trace_radius", "Radius of the bound used for the placement trace"},
		{"sentry_placement_trace_radius_canon_safety", "Extra radius used in the forward direction to compensate for the canon length"},
		{"server1", ""},
		{"server10", ""},
		{"server11", ""},
		{"server12", ""},
		{"server13", ""},
		{"server14", ""},
		{"server15", ""},
		{"server16", ""},
		{"server2", ""},
		{"server3", ""},
		{"server4", ""},
		{"server5", ""},
		{"server6", ""},
		{"server7", ""},
		{"server8", ""},
		{"server9", ""},
		{"session_immediateDeleteTinySessions", "Whether to immediately delete sessions with 1 user"},
		{"session_modify_retry_on_failure", "Enable session modify retry on failures."},
		{"session_nonblocking", "Non-blocking Session code"},
		{"shortversion", "Short game version"},
		{"showDebugAmmoCounter", "Show the debug ammo counter when unable to show ar ammo counter"},
		{"showPlaylistTotalPlayers", "Toggle the display of the total number of players in a playlist and online"},
		{"sm_cacheSpotShadows", "Cache spot shadow maps, improves shadow map performance at the cost of memory (requires vid_restart)"},
		{"sm_cacheSpotShadowsEnabled", "Enables caching of spot shadows."},
		{"sm_cacheSunShadow", "Cache sun shadow map, improves shadow map performance at the cost of memory (requires vid_restart)"},
		{"sm_cacheSunShadowEnabled", "Enables caching of sun-based shadows."},
		{"sm_cameraOffset", ""},
		{"sm_dynlightAllSModels", "Enable, from script, rendering all static models in dynamic light volume when shadow mapping"},
		{"sm_enable", "Enable shadow mapping"},
		{"sm_fastSunShadow", "Fast sun shadow"},
		{"sm_lightScore_eyeProjectDist", "When picking shadows for primary lights, measure distance from a point this far in front of the camera."},
		{"sm_lightScore_spotProjectFrac", "When picking shadows for primary lights, measure distance from a point this far in front of the camera."},
		{"sm_maxLightsWithShadows", "Limits how many primary lights can have shadow maps"},
		{"sm_minSpotLightScore", "Minimum score (based on intensity, radius, and position relative to the camera) for a spot light to have shadow maps."},
		{"sm_polygonOffsetBias", "Shadow map offset bias"},
		{"sm_polygonOffsetClamp", "Shadow map offset clamp"},
		{"sm_polygonOffsetPreset", "Shadow map polygon offset preset."},
		{"sm_polygonOffsetScale", "Shadow map offset scale"},
		{"sm_qualitySpotShadow", "Fast spot shadow"},
		{"sm_shadowUseTweaks", "Override shadow LightSet settings with tweak dvar values."},
		{"sm_spotDistCull", "Distance cull spot shadows"},
		{"sm_spotEnable", "Enable spot shadow mapping from script"},
		{"sm_spotFilterRadius", "Spot soft shadows filter radius"},
		{"sm_spotLightScoreModelScale", "Scale the calculated spot light score by this value if the light currently only affects static or script brush models."},
		{"sm_spotLightScoreRadiusPower", "Power to apply to light radius when determining spot light shadowing score (1.0 means radius scales up score a lot, 0.0 means don't scale score using radius)"},
		{"sm_spotLimit", "Limit number of spot shadows from script"},
		{"sm_spotShadowFadeTime", "How many seconds it takes for a primary light shadow map to fade in or out"},
		{"sm_strictCull", "Strict shadow map cull"},
		{"sm_sunEnable", "Enable sun shadow mapping from script"},
		{"sm_sunFilterRadius", "Sun soft shadows filter radius"},
		{"sm_sunSampleSizeNear", "Shadow sample size"},
		{"sm_sunShadowBoundsMax", "Max Shadow Bounds"},
		{"sm_sunShadowBoundsMin", "Min Shadow Bounds"},
		{"sm_sunShadowBoundsOverride", "Override Shadow Bounds"},
		{"sm_sunShadowCenter", "Sun shadow center, 0 0 0 means don't override"},
		{"sm_sunShadowCenterMode", "When false center value only used for far map, when true sets both maps"},
		{"sm_sunShadowScale", "Sun shadow scale optimization"},
		{"sm_sunShadowScaleLocked", "Lock usage of sm_sunShadowScale at 1"},
		{"sm_usedSunCascadeCount", "How many shadow cascade we are using"},
		{"snd_allowHeadphoneHRTF", "Enable HRTF over headphones"},
		{"snd_announcerDisabled", "Disable all in-game announcers"},
		{"snd_announcerVoicePrefix", "Local mp announcer voice to use"},
		{"snd_battlechatterDisabled", "Disable all in-game battle chatter"},
		{"snd_cinematicVolumeScale", "Scales the volume of Bink videos."},
		{"snd_detectedSpeakerConfig", "speaker configuration:\n0: autodetect\n1: mono\n2: stereo\n4: quadrophonic\n6: 5.1 surround\n8: 7.1 surround"},
		{"snd_dopplerAuditionEnable", "Enables doppler calculation preview mode"},
		{"snd_dopplerBaseSpeedOfSound", "The base speed of sound used in doppler calculation"},
		{"snd_dopplerEnable", "Enables doppler calculation"},
		{"snd_dopplerPitchMax", "Maximum pitch that can be legally applied by doppler"},
		{"snd_dopplerPitchMin", "Minimum pitch that can be legally applied by doppler"},
		{"snd_dopplerPlayerVelocityScale", "The scale of the player velocity, relative the the sound source velocity, when applied to the doppler calculation"},
		{"snd_dopplerSmoothing", "Smoothing factor applied to doppler to eliminate jitter or sudden acceleration changes"},
		{"snd_draw3D", "Draw the position and info of world sounds"},
		{"snd_drawInfo", "Draw debugging information for sounds"},
		{"snd_enable2D", "Enable 2D sounds"},
		{"snd_enable3D", "Enable 3D sounds"},
		{"snd_enableEq", "Enable equalization filter"},
		{"snd_enableReverb", "Enable sound reverberation"},
		{"snd_enableStream", "Enable streamed sounds"},
		{"snd_envFollowerBuffScale", "Amount of buffer to use for envelope follower. Smaller value indicates faster envelope."},
		{"snd_errorOnMissing", "Cause a Com_Error if a sound file is missing."},
		{"snd_hitsoundDisabled", "Disable the hit indicator sound"},
		{"snd_inheritSecondaryPitchVol", "Set to true for secondary aliases to inherit the pitch of the parent"},
		{"snd_levelFadeTime", "The amout of time in milliseconds for all audio to fade in at the start of a level"},
		{"snd_loadFadeTime", "Fade time for loading from a checkpoint after death."},
		{"snd_loopFadeTime", "Fade-in time for looping sounds."},
		{"snd_musicDisabled", "Disable all in-game music"},
		{"snd_musicDisabledForCustomSoundtrack", "Disable all in-game music due to user playing a custom soundtrack"},
		{"snd_occlusionDelay", "Minimum delay in (ms) between occlusion updates"},
		{"snd_occlusionLerpTime", "Time to lerp to target occlusion lerp when occluded"},
		{"snd_peakLimiterCompression", "Peak limiter compression factor. The output data is scaled by this and then normalized: F < 1 = disabled; F >= 1 enabled."},
		{"snd_peakLimiterDecay", "Peak limiter compression decay ratio."},
		{"snd_peakLimiterSustainFrames", "Number of frames to sustain the limiter peak. 1 frame = 10 msec."},
		{"snd_premixVolume", "Game sound pre-mix volume"},
		{"snd_reverbZoneOutsideFactor", "When a 3d sound is played in a different reverb zone than the player, this factor will be applied to its wet level."},
		{"snd_slaveFadeTime", "The amount of time in milliseconds for a 'slave' sound\nto fade its volumes when a master sound starts or stops"},
		{"snd_speakerConfig", "speaker configuration:\n0: autodetect\n1: mono\n2: stereo\n4: quadrophonic\n6: 5.1 surround\n8: 7.1 surround"},
		{"snd_touchStreamFilesOnLoad", "Check whether stream sound files exist while loading"},
		{"snd_useOldPanning", "Use old and busted panning"},
		{"snd_virtualChannelInfo", "Display virtual voice info."},
		{"snd_virtualMinDur", "The minimum duration (in seconds) of a sound if it is to be added to the virtual voice buffer."},
		{"snd_virtualMinPri", "The minimum priority of an alias if it is to be added to the virtual voice buffer."},
		{"snd_virtualMinTimeLeftToRevive", "The minimum time (in ms) left in a sample in order to attempt to revive it."},
		{"snd_virtualReviveVoices", "Whether or not to restore virtual voices."},
		{"snd_virtualWaitToReviveTime", "The minimum time (in ms) to wait before trying to revive the voice."},
		{"snd_volume", "Game sound master volume"},
		{"speech_active", "Are we allowed to enable Speech or not"},
		{"splitscreen", "Current game is a splitscreen game"},
		{"steam_ingame_p2p_throttle", "Time, in MS, to wait between P2P packet lookups when in-game"},
		{"stringtable_debug", "spam debug info for stringtable lookups"},
		{"sv_allowClientConsole", "Allow remote clients to access the console"},
		{"sv_allowedClan1", ""},
		{"sv_allowedClan2", ""},
		{"sv_archiveClientsPositions", "Archive the client positions to speed up SV_GetClientPositionsAtTime"},
		{"sv_checkMinPlayers", "Check min players. 0 disables"},
		{"sv_clientArchive", "Have the clients archive data to save bandwidth on the server"},
		{"sv_connectTimeout", "seconds without any message when a client is loading"},
		{"sv_cumulThinkTime", "Max client think per server 50 msec frame"},
		{"sv_error_on_baseline_failure", "Throw an error if the const baseline data is invalid."},
		{"sv_exponentialBackoffAfterNonAckedMsgs", "start exponential backoff on msg frequency if the client has not acked the last X messages"},
		{"sv_hostname", "Host name of the server"},
		{"sv_hugeSnapshotDelay", "How long to wait before building a new snapshot after a 'huge' snapshot is sent"},
		{"sv_hugeSnapshotSize", "Size of a snapshot to be considered 'huge'"},
		{"sv_kickBanTime", "Time in seconds for a player to be banned from the server after being kicked"},
		{"sv_local_client_snapshot_msec", "Local client snapshot rate, add to cl_penaltyTime"},
		{"sv_maxclients", "The maximum number of clients that can connect to a server"},
		{"sv_minPingClamp", "Clamp the minimum ping to this value"},
		{"sv_network_fps", "Number of times per second the server checks for net messages"},
		{"sv_numExpBackoffBeforeReleasingCachedSnapshots", "if a client is under an exponential backoff over this dvar, then we will release all the cached snapshot data he owns and will send him a baseline if he reconnects"},
		{"sv_paused", "Pause the server"},
		{"sv_privateClients", "Maximum number of private clients allowed on the server"},
		{"sv_privateClientsForClients", "The # of private clients (we send this to clients)"},
		{"sv_privatePassword", "password for the privateClient slots"},
		{"sv_reconnectlimit", "minimum seconds between connect messages"},
		{"sv_rejoinTimeout", "seconds without any message before allowing a rejoin"},
		{"sv_remote_client_snapshot_joiningstate_msec", "Remote client snapshot rate during join (until the client acked his first delta message)"},
		{"sv_remote_client_snapshot_msec", "Remote client snapshot rate, add to cl_penaltyTime"},
		{"sv_resetOnSpawn", "Have clients reset some player state fields when spawning rather than sending them over the network"},
		{"sv_running", "Server is running"},
		{"sv_sayName", ""},
		{"sv_showAverageBPS", "Show average bytes per second for net debugging"},
		{"sv_testValue", "Max antilag rewind"},
		{"sv_timeout", "seconds without any message"},
		{"sv_trackFrameMsecThreshold", "server frame time that will trigger script time tracking."},
		{"sv_useExtraCompress", "Use zlib compress for gamestate/baseline/score packets"},
		{"sv_zlib_threshold", "Message size threshold which triggers more aggressive compression"},
		{"sv_zombietime", "seconds to sync messages after disconnect"},
		{"svwp", "playerdata server write protection: 0 = disable, 1 = silent, 2 = kick"},
		{"syncTimeTimeout", "default timeout for sync time task (in seconds)"},
		{"sys_configSum", "Configuration checksum"},
		{"sys_configureGHz", "Normalized total CPU power, based on cpu type, count, and speed; used in autoconfigure"},
		{"sys_cpuGHz", "Measured CPU speed"},
		{"sys_cpuName", "CPU name description"},
		{"sys_gpu", "GPU description"},
		{"sys_lockThreads", "Prevents specified threads from changing CPUs; improves profiling and may fix some bugs, but can hurt performance"},
		{"sys_quitMigrateTime", "Time in msec to wait for host migration when user closes the window"},
		{"sys_smp_allowed", "Allow multi-threading"},
		{"sys_SSE", "Operating system allows Streaming SIMD Extensions"},
		{"sys_sysMB", "Physical memory in the system"},
		{"systemlink", "Current game is a system link game"},
		{"systemlink_host", "Local client is hosting system link game"},
		{"tb_report", "tb event record"},
		{"team_rebalance", "rebalance"},
		{"teambalance_option", "Selects active teambalance algorithm. 0 = heuristic 1 = exhaustive"},
		{"theater_active", "Are we allowed to show theater or not."},
		{"thermal_playerModel", "Model to draw for players when in thermal vision mode"},
		{"thermalBlurFactorNoScope", "Amount of blur to use when drawing blur through a weapon's thermal scope."},
		{"thermalBlurFactorScope", "Amount of blur to use when drawing blur through a weapon's thermal scope."},
		{"tokensEnabled", "Is token economy enabled"},
		{"tracer_explosiveColor1", "The 1st color of a bullet tracer when using explosive bullets"},
		{"tracer_explosiveColor2", "The 2nd color of a bullet tracer when using explosive bullets"},
		{"tracer_explosiveColor3", "The 3rd color of a bullet tracer when using explosive bullets"},
		{"tracer_explosiveColor4", "The 4th color of a bullet tracer when using explosive bullets"},
		{"tracer_explosiveColor5", "The 5th color of a bullet tracer when using explosive bullets"},
		{"tracer_explosiveOverride", "When turned on, will apply an override to the tracer settings when shooting explosive bullets."},
		{"tracer_explosiveWidth", "The width of a bullet tracer when using explosive bullets"},
		{"tracer_firstPersonMaxWidth", "The maximum width our OWN tracers can be when looking through our ADS"},
		{"tracer_stoppingPowerColor1", "The 1st color of a bullet tracer when using explosive bullets"},
		{"tracer_stoppingPowerColor2", "The 2nd color of a bullet tracer when using explosive bullets"},
		{"tracer_stoppingPowerColor3", "The 3rd color of a bullet tracer when using explosive bullets"},
		{"tracer_stoppingPowerColor4", "The 4th color of a bullet tracer when using explosive bullets"},
		{"tracer_stoppingPowerColor5", "The 5th color of a bullet tracer when using explosive bullets"},
		{"tracer_stoppingPowerOverride", "When turned on, will apply an override to the tracer settings when shooting explosive bullets."},
		{"tracer_stoppingPowerWidth", "The width of a bullet tracer when using explosive bullets"},
		{"tracer_thermalWidthMult", "The multiplier applied to the base width when viewed in thermal vision"},
		{"transients_verbose", "Verbose logging information for transient fastfiles."},
		{"triggerDLCEnumerationOnSocialConfigLoad", "Triggers a new DLC enumeration after social config has loaded."},
		{"ui_allow_controlschange", ""},
		{"ui_allow_teamchange", ""},
		{"ui_autodetectGamepad", "undefined"},
		{"ui_autodetectGamepadDone", "undefined"},
		{"ui_bigFont", "Big font scale"},
		{"ui_blurAmount", "Max amount to blur background menu items."},
		{"ui_blurDarkenAmount", "Amount to darken blurred UI."},
		{"ui_blurTime", "Time in milliseconds to fade in/out the blur."},
		{"ui_borderLowLightScale", "Scales the border color for the lowlight color on certain UI borders"},
		{"ui_browserFriendlyfire", "Friendly fire is active"},
		{"ui_browserKillcam", "Kill cam is active"},
		{"ui_browserMod", "UI Mod value"},
		{"ui_browserShowDedicated", "Show dedicated servers only"},
		{"ui_browserShowEmpty", "Show empty servers"},
		{"ui_browserShowFull", "Show full servers"},
		{"ui_browserShowPassword", "Show servers that are password protected"},
		{"ui_browserShowPure", "Show pure servers only"},
		{"ui_buildLocation", "Where to draw the build number"},
		{"ui_buildSize", "Font size to use for the build number"},
		{"ui_challenge_1_ref", ""},
		{"ui_challenge_2_ref", ""},
		{"ui_challenge_3_ref", ""},
		{"ui_challenge_4_ref", ""},
		{"ui_challenge_5_ref", ""},
		{"ui_challenge_6_ref", ""},
		{"ui_challenge_7_ref", ""},
		{"ui_changeclass_menu_open", ""},
		{"ui_changeteam_menu_open", ""},
		{"ui_cinematicsTimestamp", "Shows cinematics timestamp on subtitle UI elements."},
		{"ui_class_menu_open", ""},
		{"ui_connectScreenTextGlowColor", "Glow color applied to the mode and map name strings on the connect screen."},
		{"ui_contextualMenuLocation", "Contextual menu location from where you entered the store."},
		{"ui_controls_menu_open", ""},
		{"ui_currentFeederMapIndex", "Currently selected map"},
		{"ui_currentMap", "Current map index"},
		{"ui_customClassName", "Custom Class name"},
		{"ui_customModeEditName", "Name to give the currently edited custom game mode when editing is complete"},
		{"ui_customModeName", "Custom game mode name"},
		{"ui_danger_team", ""},
		{"ui_debugMode", "Draw ui debug info on the screen."},
		{"ui_disableInGameStore", "This will disable the ingame store button on the xbox live menu."},
		{"ui_disableTokenRedemption", "This will disable the token redemption option in the in-game store menu."},
		{"ui_drawCrosshair", "Whether to draw crosshairs."},
		{"ui_editSquadMemberIndex", "Which squad member is currently being edited"},
		{"ui_extraBigFont", "Extra big font scale"},
		{"ui_game_state", ""},
		{"ui_gametype", "Current game type"},
		{"ui_halftime", ""},
		{"ui_hitloc_0", ""},
		{"ui_hitloc_1", ""},
		{"ui_hitloc_2", ""},
		{"ui_hitloc_3", ""},
		{"ui_hitloc_4", ""},
		{"ui_hitloc_5", ""},
		{"ui_hitloc_damage_0", ""},
		{"ui_hitloc_damage_1", ""},
		{"ui_hitloc_damage_2", ""},
		{"ui_hitloc_damage_3", ""},
		{"ui_hitloc_damage_4", ""},
		{"ui_hitloc_damage_5", ""},
		{"ui_hud_hardcore", "Whether the HUD should be suppressed for hardcore mode"},
		{"ui_hud_obituaries", ""},
		{"ui_inactiveBaseColor", "The local player's rank/stats font color when shown in lobbies and parties"},
		{"ui_inactivePartyColor", ""},
		{"ui_inGameStoreOpen", "is the InGameStore open"},
		{"ui_inhostmigration", ""},
		{"ui_joinGametype", "Game join type"},
		{"ui_loadMenuName", "Frontend menu will start on this level instead of lockout"},
		{"ui_mapname", "Current map name"},
		{"ui_mapvote_entrya_gametype", "Primary map vote entry game type"},
		{"ui_mapvote_entrya_mapname", "Primary map vote entry map name"},
		{"ui_mapvote_entryb_gametype", "Secondary map vote entry game type"},
		{"ui_mapvote_entryb_mapname", "Secondary map vote entry map name"},
		{"ui_maxclients", "undefined"},
		{"ui_missingMapName", "Name of map to show in missing content error"},
		{"ui_mousePitch", ""},
		{"ui_multiplayer", "True if the game is multiplayer"},
		{"ui_myPartyColor", "Player name font color when in the same party as the local player"},
		{"ui_netGametype", "Game type"},
		{"ui_netGametypeName", "Displayed game type name"},
		{"ui_netSource", "The network source where:\n  0:Local\n  1:Internet\n  2:Favourites"},
		{"ui_onlineRequired", "UI requires online connection to be present."},
		{"ui_opensummary", ""},
		{"ui_override_halftime", ""},
		{"ui_partyFull", "True if the current party is full."},
		{"ui_playerPartyColor", ""},
		{"ui_playlistActionButtonAlpha", "The current alpha of the playlist selection button"},
		{"ui_playlistCategoryDisabledColor", "The color of playlist categories when disabled"},
		{"ui_playlistCategoryEnabledColor", "The color of playlist categories when enabled"},
		{"ui_promotion", ""},
		{"ui_remoteTankUseTime", ""},
		{"ui_scorelimit", ""},
		{"ui_selectedFeederMap", "Current preview game type"},
		{"ui_serverStatusTimeOut", "Time in milliseconds before a server status request times out"},
		{"ui_show_store", "Use to enable the store button"},
		{"ui_showDLCMaps", "Whether to display the DLC maps."},
		{"ui_showInfo", ""},
		{"ui_showList", "Show onscreen list of currently visible menus"},
		{"ui_showmap", ""},
		{"ui_showMenuOnly", "If set, only menus using this name will draw."},
		{"ui_showMinimap", ""},
		{"ui_sliderSteps", "The number of steps for a slider itemdef"},
		{"ui_smallFont", "Small font scale"},
		{"ui_textScrollFadeTime", "Text scrolling takes this long (seconds) to fade out at the end before restarting"},
		{"ui_textScrollPauseEnd", "Text scrolling waits this long (seconds) before starting"},
		{"ui_textScrollPauseStart", "Text scrolling waits this long (seconds) before starting"},
		{"ui_textScrollSpeed", "Speed at which text scrolls vertically"},
		{"ui_timelimit", ""},
		{"uiscript_debug", "spam debug info for the ui script"},
		{"unlock_breadcrumb_killswitch", "True to enable unlock breadcrumbs"},
		{"uno_current_tos_version", "Current Uno Terms of Service Version"},
		{"use_filtered_query_pass", "Dictates whether to use the filtered query for MMing or not"},
		{"use_weighted_dlc_exactmatch_pass", "Dictates whether to use a search weighted pass with the DLC match set to exact for MMing or not"},
		{"use_weighted_pass", "Dictates whether to use the search weighted pass for MMing or not"},
		{"useCPMarkerForCPOwnership", "If set, we will check the player inventory to see if he owns the redeemedItem for a contentPack if this contentPack is not available for the player"},
		{"useonlinestats", "Whether to use online stats when in offline modes"},
		{"useRelativeTeamColors", "Whether to use relative team colors."},
		{"userFileFetchTimeout", "default timeout for user files FETCH tasks (in seconds)"},
		{"userGroup_active", "Are we allowed to show Usergroups or not"},
		{"userGroup_cool_off_time", "Cool off time between calls to fetch the elite clan"},
		{"userGroup_coop_delay", "Delay between a player joining a coop lobby and the DW user group task starting"},
		{"userGroup_max_retry_time", "Max time that the usergroup read find can retry"},
		{"userGroup_refresh_time_secs", "Time in seconds between re-sending lobby group data to confirmed users."},
		{"userGroup_retry_step", "Step in m/s for the usegroup read retry"},
		{"userGroup_RetryTime", "Time in ms between sending lobby group data retrys."},
		{"useStatsGroups", "If true then StatsGroups are in use for all playerdata.ddl accessing."},
		{"useTagFlashSilenced", "When true, silenced weapons will use \"tag_flash_silenced\" instead of \"tag_flash\"."},
		{"using_mlg", "MLG feature on/off"},
		{"validate_apply_clamps", "True if individual stat validation failure reverts the value"},
		{"validate_apply_revert", "True if individual stat validation failure reverts the value"},
		{"validate_apply_revert_full", "True if any individual stat validation failure causes a full stats revert"},
		{"validate_clamp_assists", "The maximum number of assists a player can make in a match"},
		{"validate_clamp_experience", "The maximum experience a player can gain in a match"},
		{"validate_clamp_headshots", "The maximum number of headshots a player can make in a match"},
		{"validate_clamp_hits", "The maximum number of hits player can make in a match"},
		{"validate_clamp_kills", "The maximum number of kills a player can make in a match"},
		{"validate_clamp_losses", "The maximum number of losses a player can make in a match"},
		{"validate_clamp_misses", "The maximum number of misses player can make in a match"},
		{"validate_clamp_ties", "The maximum number of ties a player can make in a match"},
		{"validate_clamp_totalshots", "The maximum number of totalshots player can make in a match"},
		{"validate_clamp_weaponXP", "The maximum experience a weapon can gain in a match"},
		{"validate_clamp_wins", "The maximum number of wins a player can make in a match"},
		{"validate_drop_on_fail", "True if stats validation failure results in dropping from the match"},
		{"veh_aiOverSteerScale", "Scaler used to cause ai vehicles to over steer"},
		{"veh_boneControllerLodDist", "Distance at which bone controllers are not updated."},
		{"veh_boneControllerUnLodDist", "Distance at which bone controllers start updating when not moving."},
		{"vehAudio_inAirPitchDownLerp", "Rate at which the pitch lerps down"},
		{"vehAudio_inAirPitchUpLerp", "Rate at which the pitch lerps up"},
		{"vehAudio_spawnVolumeTime", "Seconds it takes for spawned vehicles to reach full volume."},
		{"vehCam_freeLook", "Enables free look mode"},
		{"vehCam_mode", "Camera modes: 1st person, 3rd person, or both"},
		{"vehDroneDebugDrawPath", "Debug render the drone draw paths."},
		{"vehHelicopterBoundsRadius", "The radius of the collision volume to be used when colliding with world geometry."},
		{"vehHelicopterDecelerationFwd", "Set the deceleration of the player helicopter (as a fraction of acceleration) in the direction the chopper is facing.  So 1.0 makes it equal to the acceleration."},
		{"vehHelicopterDecelerationSide", "Set the side-to-side deceleration of the player helicopter (as a fraction of acceleration).  So 1.0 makes it equal to the acceleration."},
		{"vehHelicopterDecelerationUp", "Set the vertical deceleration of the player helicopter (as a fraction of acceleration).  So 1.0 makes it equal to the acceleration."},
		{"vehHelicopterHeadSwayDontSwayTheTurret", "If set, the turret will not fire through the crosshairs, but straight ahead of the vehicle, when the player is not freelooking."},
		{"vehHelicopterHoverSpeedThreshold", "The speed below which the player helicopter begins to jitter the tilt, for hovering"},
		{"vehHelicopterInvertUpDown", "Invert the altitude control on the player helicopter."},
		{"vehHelicopterJitterJerkyness", "Specifies how jerky the tilt jitter should be"},
		{"vehHelicopterLookaheadTime", "How far ahead (in seconds) the player helicopter looks ahead, to avoid hard collisions.  (Like driving down the highway, you should keep 2 seconds distance between you and the vehicle in front of you)"},
		{"vehHelicopterMaxAccel", "Maximum horizontal acceleration of the player helicopter (in MPH per second)"},
		{"vehHelicopterMaxAccelVertical", "Maximum vertical acceleration of the player helicopter (in MPH per second)"},
		{"vehHelicopterMaxPitch", "Maximum pitch of the player helicopter"},
		{"vehHelicopterMaxRoll", "Maximum roll of the player helicopter"},
		{"vehHelicopterMaxSpeed", "Maximum horizontal speed of the player helicopter (in MPH)"},
		{"vehHelicopterMaxSpeedVertical", "Maximum vertical speed of the player helicopter (in MPH)"},
		{"vehHelicopterMaxYawAccel", "Maximum yaw acceleration of the player helicopter"},
		{"vehHelicopterMaxYawRate", "Maximum yaw speed of the player helicopter"},
		{"vehHelicopterPitchOffset", "The resting pitch of the helicopter"},
		{"vehHelicopterRightStickDeadzone", "Dead-zone for the axes of the right thumbstick.  This helps to better control the two axes separately."},
		{"vehHelicopterScaleMovement", "Scales down the smaller of the left stick axes."},
		{"vehHelicopterSoftCollisions", "Player helicopters have soft collisions (slow down before they collide)."},
		{"vehHelicopterStrafeDeadzone", "Dead-zone so that you can fly straight forward easily without accidentally strafing (and thus rolling)."},
		{"vehHelicopterTiltFromAcceleration", "The amount of tilt caused by acceleration"},
		{"vehHelicopterTiltFromControllerAxes", "The amount of tilt caused by the desired velocity (i.e., the amount of controller stick deflection)"},
		{"vehHelicopterTiltFromDeceleration", "The amount of tilt caused by deceleration"},
		{"vehHelicopterTiltFromFwdAndYaw", "The amount of roll caused by yawing while moving forward."},
		{"vehHelicopterTiltFromFwdAndYaw_VelAtMaxTilt", "The forward speed (as a fraction of top speed) at which the tilt due to yaw reaches is maximum value."},
		{"vehHelicopterTiltFromVelocity", "The amount of tilt caused by the current velocity"},
		{"vehHelicopterTiltMomentum", "The amount of rotational momentum the helicopter has with regards to tilting."},
		{"vehHelicopterTiltSpeed", "The rate at which the player helicopter's tilt responds"},
		{"vehHelicopterYawOnLeftStick", "The yaw speed created by the left stick when pushing the stick diagonally (e.g., moving forward and strafing slightly)."},
		{"vehicle_debug_render_spline_plane", "Do we want to render the spline plane data"},
		{"vehicle_pathsmooth", "Smoothed vehicle pathing."},
		{"vehUGVPitchTrack", "UGV body pitch orientation speed"},
		{"vehUGVRollTrack", "UGV body roll orientation speed"},
		{"vehUGVWheelInfluence", "UGV wheel influence on the orientation of the body"},
		{"vehWalkerControlMode", "Walker controls (0==move no turn, 1=move and turn, 2=move relative(tank))"},
		{"version", "Game version"},
		{"vid_xpos", "Game window horizontal position"},
		{"vid_ypos", "Game window vertical position"},
		{"viewangNow", ""},
		{"viewModelDebugNotetracks", "Enable display of viewmodel notetrack debug info."},
		{"viewModelHacks", "Enabled depth hack and remove viewmodel from shadows."},
		{"viewposNow", ""},
		{"virtualLobbyActive", "Indicates the VL is actively being displayed."},
		{"virtualLobbyAllocated", "Indicates the first VL zone has been loaded."},
		{"virtualLobbyEnabled", "VirtualLobby is enabled (must be true before loading UI zone)"},
		{"virtualLobbyInFiringRange", "VirtualLobby is in firing range mode"},
		{"virtualLobbyMap", "VirtualLobby map to load (must be set before starting vl)"},
		{"virtualLobbyMembers", "Number of members in the VirtualLobby (set by script)"},
		{"virtualLobbyPresentable", "Indicates to LUA the VirtualLobby is ready to be displayed (set by script)."},
		{"virtualLobbyReady", "Indicates to LUA the VirtualLobby is loaded and running (set by script)."},
		{"vl_clan_models_loaded", "Indicates to LUA when all models are loaded for the clan highlights so it can begin the fade-in without any popping(set by script)."},
		{"voMtxEnable", "When set (e.g. via config), will enable voice over packs"},
		{"waypointAerialIconMaxSize", "Max size of aerial targeting waypoints."},
		{"waypointAerialIconMinSize", "Min size of aerial targeting waypoints."},
		{"waypointAerialIconScale", "Base scale of aerial targeting waypoints."},
		{"waypointDebugDraw", ""},
		{"waypointDistScaleRangeMax", "Distance from player that icon distance scaling ends."},
		{"waypointDistScaleRangeMin", "Distance from player that icon distance scaling ends."},
		{"waypointDistScaleSmallest", "Smallest scale that the distance effect uses."},
		{"waypointIconHeight", ""},
		{"waypointIconWidth", ""},
		{"waypointOffscreenCornerRadius", "Size of the rounded corners."},
		{"waypointOffscreenDistanceThresholdAlpha", "Distance from the threshold over which offscreen objective icons lerp their alpha."},
		{"waypointOffscreenPadBottom", ""},
		{"waypointOffscreenPadLeft", ""},
		{"waypointOffscreenPadRight", ""},
		{"waypointOffscreenPadTop", ""},
		{"waypointOffscreenPointerDistance", "Distance from the center of the offscreen objective icon to the center its arrow."},
		{"waypointOffscreenPointerHeight", ""},
		{"waypointOffscreenPointerWidth", ""},
		{"waypointOffscreenRoundedCorners", "Off-screen icons take rounded corners when true.  90-degree corners when false."},
		{"waypointOffscreenScaleLength", "How far the offscreen icon scale travels from full to smallest scale."},
		{"waypointOffscreenScaleSmallest", "Smallest scale that the offscreen effect uses."},
		{"waypointPlayerOffsetCrouch", "For waypoints pointing to players, how high to offset off of their origin when they are prone."},
		{"waypointPlayerOffsetProne", "For waypoints pointing to players, how high to offset off of their origin when they are prone."},
		{"waypointPlayerOffsetStand", "For waypoints pointing to players, how high to offset off of their origin when they are prone."},
		{"waypointScreenCenterFadeAdsMin", "When 'waypointScreenCenterFadeRadius' enabled, minimum amount that waypoint will fade when in ads"},
		{"waypointScreenCenterFadeHipMin", "When 'waypointScreenCenterFadeRadius' enabled, minimum amount that waypoint will fade when in ads"},
		{"waypointScreenCenterFadeRadius", "Radius from screen center that a waypoint will start fading out. Setting to 0 will turn this off"},
		{"waypointSplitscreenScale", "Scale applied to waypoint icons in splitscreen views."},
		{"waypointTweakY", ""},
		{"weap_thermoDebuffMod", ""},
		{"wideScreen", "True if the game video is running in 16x9 aspect, false if 4x3."},
		{"winvoice_loopback", "Echo microphone input locally"},
		{"winvoice_mic_mute", "Mute the microphone"},
		{"winvoice_mic_outTime", "Microphone voice amount of silence before we cut the mic"},
		{"winvoice_mic_reclevel", "Microphone recording level"},
		{"winvoice_mic_scaler", "Microphone scaler value"},
		{"winvoice_mic_threshold", "Microphone voice threshold"},
		{"winvoice_save_voice", "Write voice data to a file"},
		{"xanim_disableIK", "Disable inverse kinematics solvers"},
		{"xblive_competitionmatch", "MLG Rules?"},
		{"xblive_hostingprivateparty", "true only if we're hosting a party"},
		{"xblive_loggedin", "User is logged into xbox live"},
		{"xblive_privatematch", "Current game is a private match"},
		{"xblive_privatematch_solo", "Current game is an Extinction solo match"},
		{"xphys_maxJointPositionError", "If a joints with position error exceeding this value is detected, then the whole xphys system gets snapped back to the animation pose"},
	};

	std::string dvar_get_description(const std::string& name)
	{
		const auto lower = utils::string::to_lower(name);
		for (std::uint32_t i = 0; i < dvar_list.size(); i++)
		{
			if (utils::string::to_lower(dvar_list[i].name) == lower)
			{
				return dvar_list[i].description;
			}
		}

		return {};
	}

	bool can_add_dvar_to_list(std::string name)
	{
		const auto lower = utils::string::to_lower(name);
		for (std::uint32_t i = 0; i < dvar_list.size(); i++)
		{
			if (utils::string::to_lower(dvar_list[i].name) == lower)
			{
				return false;
			}
		}

		return true;
	}

	game::dvar_t* register_int(const std::string& name, int value, int min, int max,
		game::DvarFlags flags, const std::string& description)
	{
		const auto hash = game::generateHashValue(name.data());

		if (can_add_dvar_to_list(name))
		{
			dvar_list.push_back({name, description});
		}

		return game::Dvar_RegisterInt(hash, "", value, min, max, flags);
	}

	game::dvar_t* register_bool(const std::string& name, bool value,
		game::DvarFlags flags, const std::string& description)
	{
		const auto hash = game::generateHashValue(name.data());

		if (can_add_dvar_to_list(name))
		{
			dvar_list.push_back({name, description});
		}

		return game::Dvar_RegisterBool(hash, "", value, flags);
	}

	game::dvar_t* register_string(const std::string& name, const char* value,
		game::DvarFlags flags, const std::string& description)
	{
		const auto hash = game::generateHashValue(name.data());

		if (can_add_dvar_to_list(name))
		{
			dvar_list.push_back({name, description});
		}

		return game::Dvar_RegisterString(hash, "", value, flags);
	}

	game::dvar_t* register_float(const std::string& name, float value, float min,
		float max, game::DvarFlags flags, const std::string& description)
	{
		const auto hash = game::generateHashValue(name.data());

		if (can_add_dvar_to_list(name))
		{
			dvar_list.push_back({name, description});
		}

		return game::Dvar_RegisterFloat(hash, "", value, min, max, flags);
	}

	game::dvar_t* register_vec4(const std::string& name, float x, float y, float z,
		float w, float min, float max, game::DvarFlags flags, const std::string& description)
	{
		const auto hash = game::generateHashValue(name.data());

		if (can_add_dvar_to_list(name))
		{
			dvar_list.push_back({name, description});
		}

		return game::Dvar_RegisterVec4(hash, "", x, y, z, w, min, max, flags);
	}
}
